 -- $Id: Atlas_WrathoftheLichKing.lua 24 2017-04-29 14:58:55Z arith $
--[[

	Atlas, a World of Warcraft instance map browser
	Copyright 2011 ~ 2017 - Arith Hsu, Atlas Team <atlas.addon at gmail dot com>

	This file is part of Atlas.

	Atlas is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local BF = Atlas_GetLocaleLibBabble("LibBabble-Faction-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("Atlas_WrathoftheLichKing");
local ALC = LibStub("AceLocale-3.0"):GetLocale("Atlas");

local BLUE = "|cff6666ff";
local GREN = "|cff66cc33";
local GREY = "|cff999999";
local LBLU = "|cff33cccc";
local _RED = "|cffcc3333";
local ORNG = "|cffcc9933";
local PINK = "|ccfcc33cc";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local YLOW = "|cffcccc33";
local INDENT = "      ";

local myMaps = {
	AhnKahet = {
		ZoneName = { BZ["Ahn'kahet: The Old Kingdom"] };
		Location = { BZ["Dragonblight"] };
		DungeonID = "218";
		DungeonHeroicID = "219";
		Acronym = L["AK, Kahet"];
		WorldMapID = "522";
		JournalInstanceID = "271";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Seer Ixit"] };
		{ BLUE.." B) "..ALC["Exit"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Elder Nadox", 580), 580 };
		{ WHIT.." 2) "..Atlas_GetBossName("Prince Taldaram", 581), 581 };
		{ WHIT.." 3) "..Atlas_GetBossName("Amanitar", 583)..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 583 };
		{ WHIT.." 4) "..Atlas_GetBossName("Jedoga Shadowseeker", 582), 582 };
		{ WHIT.." 5) "..Atlas_GetBossName("Herald Volazj", 584), 584 };
		{ GREN.." 1') "..L["Ahn'kahet Brazier"], 10003 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Ahn'kahet: The Old Kingdom", "ac=481" };
		{ "Volazj's Quick Demise", "ac=1862" };
		{ "Respect Your Elders", "ac=2038" };
		{ "Volunteer Work", "ac=2056" };
		{ "Heroic: Ahn'kahet: The Old Kingdom", "ac=492" };
		{ "Heroic: Ahn'kahet: The Old Kingdom Guild Run", "ac=5098" };
	};
	AzjolNerub = {
		ZoneName = { BZ["Azjol-Nerub"] };
		Location = { BZ["Dragonblight"] };
		DungeonID = "204";
		DungeonHeroicID = "241";
		Acronym = L["AN, Nerub"];
		WorldMapID = "533";
		JournalInstanceID = "272";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Reclaimer A'zak"] };
		{ BLUE.." B) "..ALC["Connection"], 10002 };
		{ BLUE.." C) "..ALC["Exit"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("Krik'thir the Gatewatcher", 585), 585 };
		{ WHIT..INDENT..L["Watcher Gashra"] };
		{ WHIT..INDENT..L["Watcher Narjil"] };
		{ WHIT..INDENT..L["Watcher Silthik"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Hadronox", 586), 586 };
		{ WHIT.." 3) "..Atlas_GetBossName("Anub'arak", 587), 587 };
		{ GREN.." 1') "..L["Elder Nurgen"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10004 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Azjol-Nerub", "ac=480" };
		{ "Watch Him Die", "ac=1296" };
		{ "Hadronox Denied", "ac=1297" };
		{ "Gotta Go!", "ac=1860" };
		{ "Heroic: Azjol-Nerub", "ac=491" };
		{ "Heroic: Azjol-Nerub Guild Run", "ac=5097" };
	};
	CoTOldStratholme = {
		ZoneName = { BZ["Caverns of Time"]..ALC["Colon"]..BZ["The Culling of Stratholme"] };
		Location = { BZ["Tanaris"] };
		DungeonID = "209";
		DungeonHeroicID = "210";
		Acronym = L["CoT-Strat"];
		WorldMapID = "521";
		JournalInstanceID = "279";
		Module = "Atlas_WrathoftheLichKing";
		{ PURP..ALC["Event"]..ALC["Colon"]..L["The Culling of Stratholme"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Exit"]..ALC["L-Parenthesis"]..ALC["Portal"]..ALC["R-Parenthesis"], 10002 };
		{ ORNG.." X) "..L["Scourge Invasion Points"], 10003 };
		{ WHIT..INDENT..ALC["Wave 5"]..ALC["Colon"]..Atlas_GetBossName("Meathook", 611), 611 };
		{ WHIT..INDENT..ALC["Wave 10"]..ALC["Colon"]..Atlas_GetBossName("Salramm the Fleshcrafter", 612), 612 };
		{ WHIT.." 3) "..Atlas_GetBossName("Chrono-Lord Epoch", 613), 613 };
		{ WHIT.." 4) "..Atlas_GetBossName("Infinite Corruptor")..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["R-Parenthesis"], 10004 };
		{ GREN..INDENT..L["Guardian of Time"] };
		{ WHIT.." 5) "..Atlas_GetBossName("Mal'Ganis", 614), 614 };
		{ GREN..INDENT..L["Chromie"] };
		{ GREN.." 1') "..L["Chromie"], 10005 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Culling of Stratholme", "ac=479" };
		{ "The Culling of Time", "ac=1817" };
		{ "Zombiefest!", "ac=1872" };
		{ "Heroic: The Culling of Stratholme", "ac=500" };
		{ "Heroic: The Culling of Stratholme Guild Run", "ac=5106" };
	};
	DrakTharonKeep = {
		ZoneName = { BZ["Drak'Tharon Keep"] };
		Location = { BZ["Grizzly Hills"] };
		DungeonID = "214";
		DungeonHeroicID = "215";
		Acronym = L["DTK"];
		WorldMapID = "534";
		JournalInstanceID = "273";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Image of Drakuru"] };
		{ GREN..INDENT..L["Kurzel"] };
		{ BLUE.." B-C) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Trollgore", 588), 588 };
		{ WHIT.." 2) "..Atlas_GetBossName("Novos the Summoner", 589), 589 };
		{ WHIT.." 3) "..Atlas_GetBossName("King Dred", 590), 590 };
		{ WHIT.." 4) "..Atlas_GetBossName("The Prophet Tharon'ja", 591), 591 };
		{ GREN.." 1') "..L["Elder Kilias"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10003 };
		{ GREN.." 2') "..L["Drakuru's Brazier"], 10004 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Drak'Tharon Keep", "ac=482" };
		{ "Consumption Junction", "ac=2151" };
		{ "Better Off Dred", "ac=2039" };
		{ "Oh Novos!", "ac=2057" };
		{ "Heroic: Drak'Tharon Keep", "ac=493" };
		{ "Heroic: Drak'Tharon Keep Guild Run", "ac=5099" };
	};
	FHHallsOfReflection = {
		ZoneName = { BZ["The Frozen Halls"]..ALC["Colon"]..BZ["Halls of Reflection"] };
		Location = { BZ["Icecrown Citadel"] };
		DungeonID = "255";
		DungeonHeroicID = "256";
		Acronym = L["HoR"]..ALC["Comma"]..L["FH3"];
		WorldMapID = "603";
		JournalInstanceID = "276";
		Module = "Atlas_WrathoftheLichKing";
		{ ORNG..ALC["Attunement Required"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Portal"]..ALC["L-Parenthesis"]..BZ["Dalaran"]..ALC["R-Parenthesis"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Falric", 601)..ALC["L-Parenthesis"]..ALC["Wave 5"]..ALC["R-Parenthesis"], 601 };
		{ WHIT.." 2) "..Atlas_GetBossName("Marwyn", 602)..ALC["L-Parenthesis"]..ALC["Wave 10"]..ALC["R-Parenthesis"], 602 };
		{ WHIT.." 3) "..Atlas_GetBossName("Escape from Arthas", 603)..ALC["L-Parenthesis"]..ALC["Event"]..ALC["R-Parenthesis"], 603 };
		{ GREN..INDENT..L["The Captain's Chest"] };
		{ GREN.." 1') "..L["Lady Jaina Proudmoore"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10003 };
		{ GREN..INDENT..L["Archmage Koreln <Kirin Tor>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Lady Sylvanas Windrunner <Banshee Queen>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Loralen"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Halls of Reflection", "ac=4518" };
		{ "We're Not Retreating; We're Advancing in a Different Direction.", "ac=4526" };
		{ "Heroic: The Halls of Reflection", "ac=4521" };
		{ "Heroic: The Halls of Reflection Guild Run", "ac=5114" };
	};
	FHPitOfSaron = {
		ZoneName = { BZ["The Frozen Halls"]..ALC["Colon"]..BZ["Pit of Saron"] };
		Location = { BZ["Icecrown Citadel"] };
		DungeonID = "253";
		DungeonHeroicID = "254";
		Acronym = L["PoS"]..ALC["Comma"]..L["FH2"];
		WorldMapID = "602";
		JournalInstanceID = "278";
		Module = "Atlas_WrathoftheLichKing";
		{ ORNG..ALC["Attunement Required"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Portal"]..ALC["L-Parenthesis"]..BZ["Halls of Reflection"]..ALC["R-Parenthesis"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Forgemaster Garfrost", 608), 608 };
		{ GREN..INDENT..L["Martin Victus"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Gorkun Ironskull"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Ick & Krick", 609), 609 };
		{ WHIT.." 3) "..Atlas_GetBossName("Scourgelord Tyrannus", 610), 610 };
		{ WHIT..INDENT..L["Rimefang"] };
		{ GREN.."1') "..L["Lady Jaina Proudmoore"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10003 };
		{ GREN..INDENT..L["Archmage Koreln <Kirin Tor>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Archmage Elandra <Kirin Tor>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Lady Sylvanas Windrunner <Banshee Queen>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Loralen"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Kalira"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Pit of Saron", "ac=4517" };
		{ "Doesn't Go to Eleven", "ac=4524" };
		{ "Don't Look Up", "ac=4525" };
		{ "Heroic: The Pit of Saron", "ac=4520" };
		{ "Heroic: The Pit of Saron Guild Run", "ac=5113" };
	};
	FHTheForgeOfSouls = {
		ZoneName = { BZ["The Frozen Halls"]..ALC["Colon"]..BZ["The Forge of Souls"] };
		Location = { BZ["Icecrown Citadel"] };
		DungeonID = "251";
		DungeonHeroicID = "252";
		Acronym = L["FoS"]..ALC["Comma"]..L["FH1"];
		WorldMapID = "601";
		JournalInstanceID = "280";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Portal"]..ALC["L-Parenthesis"]..BZ["Pit of Saron"]..ALC["R-Parenthesis"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Bronjahm", 615), 615 };
		{ WHIT.." 2) "..Atlas_GetBossName("Devourer of Souls", 616), 616 };
		{ GREN.." 1') "..L["Lady Jaina Proudmoore"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10003 };
		{ GREN..INDENT..L["Archmage Koreln <Kirin Tor>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Archmage Elandra <Kirin Tor>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Lady Sylvanas Windrunner <Banshee Queen>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Loralen"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Kalira"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Forge of Souls", "ac=4516" };
		{ "Soul Power", "ac=4522" };
		{ "Three Faced", "ac=4523" };
		{ "Heroic: The Forge of Souls", "ac=4519" };
		{ "Heroic: The Forge of Souls Guild Run", "ac=5112" };
	};
	Gundrak = {
		ZoneName = { BZ["Gundrak"] };
		Location = { BZ["Zul'Drak"] };
		DungeonID = "216";
		DungeonHeroicID = "217";
		Acronym = L["Gun"];
		WorldMapID = "530";
		JournalInstanceID = "274";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Chronicler Bah'Kini"]..ALC["Slash"]..L["Tol'mar"] };
		{ BLUE.." B) "..ALC["Exit"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Slad'ran", 592), 592 };
		{ WHIT.." 2) "..Atlas_GetBossName("Drakkari Colossus", 593), 593 };
		{ WHIT.." 3) "..Atlas_GetBossName("Moorabi", 594), 594 };
		{ WHIT.." 4) "..Atlas_GetBossName("Eck the Ferocious", 595)..ALC["L-Parenthesis"]..ALC["Heroic"]..ALC["Comma"]..ALC["Summon"]..ALC["R-Parenthesis"], 595 };
		{ WHIT.." 5) "..Atlas_GetBossName("Gal'darah", 596), 596 };
		{ GREN.." 1') "..L["Elder Ohanzee"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10003 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Gundrak", "ac=484" };
		{ "What the Eck?", "ac=1864" };
		{ "Share The Love", "ac=2152" };
		{ "Less-rabi", "ac=2040" };
		{ "Snakes. Why'd It Have To Be Snakes?", "ac=2058" };
		{ "Heroic: Gundrak", "ac=495" };
		{ "Heroic: Gundrak Guild Run", "ac=5101" };
	};
	IcecrownEnt = {
		ZoneName = { BZ["Icecrown Citadel"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Icecrown"] };
		LevelRange = "80-83";
		MinLevel = "75";
		PlayerLimit = "5/10/25";
		Acronym = L["IC"];
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["The Forge of Souls"], 10002 };
		{ BLUE.." C) "..BZ["Pit of Saron"], 10003 };
		{ BLUE.." D) "..BZ["Halls of Reflection"], 10004 };
		{ BLUE.." E) "..BZ["Icecrown Citadel"], 10005 };
		{ GREN.." 1') "..ALC["Meeting Stone"], 10006 };
	};
	IcecrownCitadelA = {
		ZoneName = { BZ["Icecrown Citadel"]..ALC["MapA"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"] };
		Location = { BZ["Icecrown"] };
		DungeonID = "279";
		DungeonHeroicID = "280";
		Acronym = L["IC"];
		PlayerLimit = "10/25";
		WorldMapID = "604";
		DungeonLevel = "1";
		JournalInstanceID = "758";
		Module = "Atlas_WrathoftheLichKing";
		NextMap = "IcecrownCitadelB";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Ashen Verdict"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Elevator"], 10002 };
		{ BLUE.." C) "..L["To next map"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("Lord Marrowgar", 1624), 1624 };
		{ WHIT.." 2) "..Atlas_GetBossName("Lady Deathwhisper", 1625), 1625 };
		{ WHIT.." 3) "..Atlas_GetBossName("Icecrown Gunship Battle", 1626)..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 1626 };
		{ WHIT.." 4) "..Atlas_GetBossName("Icecrown Gunship Battle", 1627)..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"], 1627 };
		{ WHIT.." 5) "..Atlas_GetBossName("Deathbringer Saurfang", 1628), 1628 };
		{ GREN.." 1') "..BZ["Light's Hammer"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10009 };
		{ GREN.." 2') "..ALC["Portal"]..ALC["L-Parenthesis"]..BZ["Dalaran"]..ALC["R-Parenthesis"], 10012 };
		{ GREN.." 3') "..BZ["Oratory of the Damned"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10010 };
		{ GREN.." 4') "..BZ["Rampart of Skulls"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["Comma"]..ALC["Lower"]..ALC["R-Parenthesis"], 10011 };
		{ GREN..INDENT..BZ["Deathbringer's Rise"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["Comma"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Storming the Citadel (10 player)", "ac=4531" };
		{ "Storming the Citadel (25 player)", "ac=4604" };
		{ "The Plagueworks (10 player)", "ac=4528" };
		{ "The Plagueworks (25 player)", "ac=4605" };
		{ "The Crimson Hall (10 player)", "ac=4529" };
		{ "The Crimson Hall (25 player)", "ac=4606" };
		{ "The Frostwing Halls (10 player)", "ac=4527" };
		{ "The Frostwing Halls (25 player)", "ac=4607" };
		{ "The Frozen Throne (10 player)", "ac=4530" };
		{ "The Frozen Throne (25 player)", "ac=4597" };
		{ "Bane of the Fallen King", "ac=4583" };
		{ "The Light of Dawn", "ac=4584" };
		{ "Fall of the Lich King (10 player)", "ac=4532" };
		{ "Boned (10 player)", "ac=4534" };
		{ "Boned (25 player)", "ac=4610" };
		{ "Full House (10 player)", "ac=4535" };
		{ "Full House (25 player)", "ac=4611" };
		{ "I'm on a Boat (10 player)", "ac=4536" };
		{ "I'm on a Boat (25 player)", "ac=4612" };
		{ "I've Gone and Made a Mess (10 player)", "ac=4537" };
		{ "I've Gone and Made a Mess (25 player)", "ac=4613" };
		{ "Dances with Oozes (10 player)", "ac=4538" };
		{ "Dances with Oozes (25 player)", "ac=4614" };
		{ "Flu Shot Shortage (10 player)", "ac=4577" };
		{ "Flu Shot Shortage (25 player)", "ac=4615" };
		{ "Nausea, Heartburn, Indigestion... (10 player)", "ac=4578" };
		{ "Nausea, Heartburn, Indigestion... (25 player)", "ac=4616" };
		{ "The Orb Whisperer (10 player)", "ac=4582" };
		{ "The Orb Whisperer (25 player)", "ac=4617" };
		{ "Once Bitten, Twice Shy (10 player)", "ac=4539" };
		{ "Once Bitten, Twice Shy (25 player)", "ac=4618" };
		{ "Portal Jockey (10 player)", "ac=4579" };
		{ "Portal Jockey (25 player)", "ac=4619" };
		{ "All You Can Eat (10 player)", "ac=4580" };
		{ "All You Can Eat (25 player)", "ac=4620" };
		{ "Been Waiting a Long Time for This (10 player)", "ac=4601" };
		{ "Been Waiting a Long Time for This (25 player)", "ac=4621" };
		{ "Neck-Deep in Vile (10 player)", "ac=4581" };
		{ "Neck-Deep in Vile (25 player)", "ac=4622" };
		{ "The Frozen Throne - Guild Edition", "ac=5023" };
		{ "Heroic: Storming the Citadel (10 player)", "ac=4628" };
		{ "Heroic: Storming the Citadel (25 player)", "ac=4632" };
		{ "Heroic: The Plagueworks (10 player)", "ac=4629" };
		{ "Heroic: The Plagueworks (25 player)", "ac=4633" };
		{ "Heroic: The Crimson Hall (10 player)", "ac=4630" };
		{ "Heroic: The Crimson Hall (25 player)", "ac=4634" };
		{ "Heroic: The Frostwing Halls (10 player)", "ac=4631" };
		{ "Heroic: The Frostwing Halls (25 player)", "ac=4635" };
		{ "Heroic: Fall of the Lich King (10 player)", "ac=4636" };
		{ "Realm First! Fall of the Lich King", "ac=4576" };
	};
	IcecrownCitadelB = {
		ZoneName = { BZ["Icecrown Citadel"]..ALC["MapB"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"] };
		Location = { BZ["Icecrown"] };
		DungeonID = "279";
		DungeonHeroicID = "280";
		Acronym = L["IC"];
		PlayerLimit = "10/25";
		WorldMapID = "604";
		DungeonLevel = "5";
		JournalInstanceID = "758";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "IcecrownCitadelA";
		NextMap = "IcecrownCitadelC";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Ashen Verdict"] };
		{ BLUE.." C) "..L["From previous map"], 10001 };
		{ BLUE.." D-H) "..ALC["Connection"], 10002 };
		{ BLUE.." I) "..L["To next map"], 10003 };
		{ WHIT.." 6) "..L["Stinky"], 10004 };
		{ WHIT.." 7) "..L["Precious"], 10005 };
		{ WHIT.." 8) "..Atlas_GetBossName("Festergut", 1629), 1629 };
		{ WHIT.." 9) "..Atlas_GetBossName("Rotface", 1630), 1630 };
		{ WHIT.."10) "..Atlas_GetBossName("Professor Putricide", 1631), 1631 };
		{ WHIT.."11) "..Atlas_GetBossName("Blood Prince Council", 1632), 1632 };
		{ WHIT..INDENT..Atlas_GetBossName("Prince Keleseth") };
		{ WHIT..INDENT..Atlas_GetBossName("Prince Taldaram") };
		{ WHIT..INDENT..Atlas_GetBossName("Prince Valanar") };
		{ WHIT.."12) "..Atlas_GetBossName("Blood-Queen Lana'thel", 1633), 1633 };
		{ WHIT.."13) "..L["Sister Svalna"], 10011 };
		{ WHIT.."14) "..Atlas_GetBossName("Valithria Dreamwalker", 1634), 1634 };
		{ WHIT.."15) "..Atlas_GetBossName("Sindragosa", 1635), 1635 };
		{ WHIT..INDENT..L["Rimefang"] };
		{ WHIT..INDENT..L["Spinestalker"] };
		{ GREN.." 4') "..L["Upper Spire"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10014 };
		{ GREN.." 5') "..L["Sindragosa's Lair"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10015 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Storming the Citadel (10 player)", "ac=4531" };
		{ "Storming the Citadel (25 player)", "ac=4604" };
		{ "The Plagueworks (10 player)", "ac=4528" };
		{ "The Plagueworks (25 player)", "ac=4605" };
		{ "The Crimson Hall (10 player)", "ac=4529" };
		{ "The Crimson Hall (25 player)", "ac=4606" };
		{ "The Frostwing Halls (10 player)", "ac=4527" };
		{ "The Frostwing Halls (25 player)", "ac=4607" };
		{ "The Frozen Throne (10 player)", "ac=4530" };
		{ "The Frozen Throne (25 player)", "ac=4597" };
		{ "Bane of the Fallen King", "ac=4583" };
		{ "The Light of Dawn", "ac=4584" };
		{ "Fall of the Lich King (10 player)", "ac=4532" };
		{ "Boned (10 player)", "ac=4534" };
		{ "Boned (25 player)", "ac=4610" };
		{ "Full House (10 player)", "ac=4535" };
		{ "Full House (25 player)", "ac=4611" };
		{ "I'm on a Boat (10 player)", "ac=4536" };
		{ "I'm on a Boat (25 player)", "ac=4612" };
		{ "I've Gone and Made a Mess (10 player)", "ac=4537" };
		{ "I've Gone and Made a Mess (25 player)", "ac=4613" };
		{ "Dances with Oozes (10 player)", "ac=4538" };
		{ "Dances with Oozes (25 player)", "ac=4614" };
		{ "Flu Shot Shortage (10 player)", "ac=4577" };
		{ "Flu Shot Shortage (25 player)", "ac=4615" };
		{ "Nausea, Heartburn, Indigestion... (10 player)", "ac=4578" };
		{ "Nausea, Heartburn, Indigestion... (25 player)", "ac=4616" };
		{ "The Orb Whisperer (10 player)", "ac=4582" };
		{ "The Orb Whisperer (25 player)", "ac=4617" };
		{ "Once Bitten, Twice Shy (10 player)", "ac=4539" };
		{ "Once Bitten, Twice Shy (25 player)", "ac=4618" };
		{ "Portal Jockey (10 player)", "ac=4579" };
		{ "Portal Jockey (25 player)", "ac=4619" };
		{ "All You Can Eat (10 player)", "ac=4580" };
		{ "All You Can Eat (25 player)", "ac=4620" };
		{ "Been Waiting a Long Time for This (10 player)", "ac=4601" };
		{ "Been Waiting a Long Time for This (25 player)", "ac=4621" };
		{ "Neck-Deep in Vile (10 player)", "ac=4581" };
		{ "Neck-Deep in Vile (25 player)", "ac=4622" };
		{ "The Frozen Throne - Guild Edition", "ac=5023" };
		{ "Heroic: Storming the Citadel (10 player)", "ac=4628" };
		{ "Heroic: Storming the Citadel (25 player)", "ac=4632" };
		{ "Heroic: The Plagueworks (10 player)", "ac=4629" };
		{ "Heroic: The Plagueworks (25 player)", "ac=4633" };
		{ "Heroic: The Crimson Hall (10 player)", "ac=4630" };
		{ "Heroic: The Crimson Hall (25 player)", "ac=4634" };
		{ "Heroic: The Frostwing Halls (10 player)", "ac=4631" };
		{ "Heroic: The Frostwing Halls (25 player)", "ac=4635" };
		{ "Heroic: Fall of the Lich King (10 player)", "ac=4636" };
		{ "Realm First! Fall of the Lich King", "ac=4576" };
	};
	IcecrownCitadelC = {
		ZoneName = { BZ["Icecrown Citadel"]..ALC["MapC"]..ALC["L-Parenthesis"]..BZ["The Frozen Throne"]..ALC["R-Parenthesis"] };
		Location = { BZ["Icecrown"] };
		DungeonID = "279";
		DungeonHeroicID = "280";
		Acronym = L["IC"];
		PlayerLimit = "10/25";
		WorldMapID = "604";
		DungeonLevel = "7";
		JournalInstanceID = "758";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "IcecrownCitadelB";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["The Ashen Verdict"] };
		{ BLUE.." I) "..L["From previous map"], 10001 };
		{ WHIT.."16) "..Atlas_GetBossName("The Lich King", 1636), 1636 };
		{ "Storming the Citadel (10 player)", "ac=4531" };
		{ "Storming the Citadel (25 player)", "ac=4604" };
		{ "The Plagueworks (10 player)", "ac=4528" };
		{ "The Plagueworks (25 player)", "ac=4605" };
		{ "The Crimson Hall (10 player)", "ac=4529" };
		{ "The Crimson Hall (25 player)", "ac=4606" };
		{ "The Frostwing Halls (10 player)", "ac=4527" };
		{ "The Frostwing Halls (25 player)", "ac=4607" };
		{ "The Frozen Throne (10 player)", "ac=4530" };
		{ "The Frozen Throne (25 player)", "ac=4597" };
		{ "Bane of the Fallen King", "ac=4583" };
		{ "The Light of Dawn", "ac=4584" };
		{ "Fall of the Lich King (10 player)", "ac=4532" };
		{ "Boned (10 player)", "ac=4534" };
		{ "Boned (25 player)", "ac=4610" };
		{ "Full House (10 player)", "ac=4535" };
		{ "Full House (25 player)", "ac=4611" };
		{ "I'm on a Boat (10 player)", "ac=4536" };
		{ "I'm on a Boat (25 player)", "ac=4612" };
		{ "I've Gone and Made a Mess (10 player)", "ac=4537" };
		{ "I've Gone and Made a Mess (25 player)", "ac=4613" };
		{ "Dances with Oozes (10 player)", "ac=4538" };
		{ "Dances with Oozes (25 player)", "ac=4614" };
		{ "Flu Shot Shortage (10 player)", "ac=4577" };
		{ "Flu Shot Shortage (25 player)", "ac=4615" };
		{ "Nausea, Heartburn, Indigestion... (10 player)", "ac=4578" };
		{ "Nausea, Heartburn, Indigestion... (25 player)", "ac=4616" };
		{ "The Orb Whisperer (10 player)", "ac=4582" };
		{ "The Orb Whisperer (25 player)", "ac=4617" };
		{ "Once Bitten, Twice Shy (10 player)", "ac=4539" };
		{ "Once Bitten, Twice Shy (25 player)", "ac=4618" };
		{ "Portal Jockey (10 player)", "ac=4579" };
		{ "Portal Jockey (25 player)", "ac=4619" };
		{ "All You Can Eat (10 player)", "ac=4580" };
		{ "All You Can Eat (25 player)", "ac=4620" };
		{ "Been Waiting a Long Time for This (10 player)", "ac=4601" };
		{ "Been Waiting a Long Time for This (25 player)", "ac=4621" };
		{ "Neck-Deep in Vile (10 player)", "ac=4581" };
		{ "Neck-Deep in Vile (25 player)", "ac=4622" };
		{ "The Frozen Throne - Guild Edition", "ac=5023" };
		{ "Heroic: Storming the Citadel (10 player)", "ac=4628" };
		{ "Heroic: Storming the Citadel (25 player)", "ac=4632" };
		{ "Heroic: The Plagueworks (10 player)", "ac=4629" };
		{ "Heroic: The Plagueworks (25 player)", "ac=4633" };
		{ "Heroic: The Crimson Hall (10 player)", "ac=4630" };
		{ "Heroic: The Crimson Hall (25 player)", "ac=4634" };
		{ "Heroic: The Frostwing Halls (10 player)", "ac=4631" };
		{ "Heroic: The Frostwing Halls (25 player)", "ac=4635" };
		{ "Heroic: Fall of the Lich King (10 player)", "ac=4636" };
		{ "Realm First! Fall of the Lich King", "ac=4576" };
	};
	Naxxramas = {
		ZoneName = { BZ["Naxxramas"] };
		Location = { BZ["Dragonblight"] };
		DungeonID = "159";
		DungeonHeroicID = "227";
		Acronym = L["Nax"];
		PlayerLimit = "10/25";
		WorldMapID = "535";
		JournalInstanceID = "754";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Mr. Bigglesworth"]..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"] };
		{ WHIT..BZ["The Construct Quarter"] };
		{ WHIT..INDENT.."1) "..Atlas_GetBossName("Patchwerk", 1610), 1610 };
		{ WHIT..INDENT.."2) "..Atlas_GetBossName("Grobbulus", 1611), 1611 };
		{ WHIT..INDENT.."3) "..Atlas_GetBossName("Gluth", 1612), 1612 };
		{ WHIT..INDENT.."4) "..Atlas_GetBossName("Thaddius", 1613), 1613 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Stalagg") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Feugen") };
		{ ORNG..BZ["The Arachnid Quarter"] };
		{ ORNG..INDENT.."1) "..Atlas_GetBossName("Anub'Rekhan", 1601), 1601 };
		{ ORNG..INDENT.."2) "..Atlas_GetBossName("Grand Widow Faerlina", 1602), 1602 };
		{ ORNG..INDENT.."3) "..Atlas_GetBossName("Maexxna", 1603), 1603 };
		{ _RED..BZ["The Military Quarter"] };
		{ _RED..INDENT.."1) "..Atlas_GetBossName("Instructor Razuvious", 1607), 1607 };
		{ _RED..INDENT.."2) "..Atlas_GetBossName("Gothik the Harvester", 1608), 1608 };
		{ _RED..INDENT.."3) "..Atlas_GetBossName("The Four Horsemen", 1609), 1609 };
		{ _RED..INDENT..INDENT..Atlas_GetBossName("Thane Korth'azz") };
		{ _RED..INDENT..INDENT..Atlas_GetBossName("Lady Blaumeux") };
		{ _RED..INDENT..INDENT..Atlas_GetBossName("Baron Rivendare") };
		{ _RED..INDENT..INDENT..Atlas_GetBossName("Sir Zeliek") };
		{ GREN..INDENT..INDENT..Atlas_GetBossName("Four Horsemen Chest") };
		{ PURP..BZ["The Plague Quarter"] };
		{ PURP..INDENT.."1) "..Atlas_GetBossName("Noth the Plaguebringer", 1604), 1604 };
		{ PURP..INDENT.."2) "..Atlas_GetBossName("Heigan the Unclean", 1605), 1605 };
		{ PURP..INDENT.."3) "..Atlas_GetBossName("Loatheb", 1606), 1606 };
		{ GREN..L["Frostwyrm Lair"] };
		{ GREN..INDENT.."1) "..Atlas_GetBossName("Sapphiron", 1614), 1614 };
		{ GREN..INDENT.."2) "..Atlas_GetBossName("Kel'Thuzad", 1615), 1615 };
		{ "" };
		{ GREN.." 1') "..L["Teleporter to Middle"], 10017 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Arachnid Quarter (10 player)", "ac=562" };
		{ "The Arachnid Quarter (25 player)", "ac=563" };
		{ "The Construct Quarter (10 player)", "ac=564" };
		{ "The Construct Quarter (25 player)", "ac=565" };
		{ "The Plague Quarter (10 player)", "ac=566" };
		{ "The Plague Quarter (25 player)", "ac=567" };
		{ "The Military Quarter (10 player)", "ac=568" };
		{ "The Military Quarter (25 player)", "ac=569" };
		{ "Sapphiron's Demise (10 player)", "ac=572" };
		{ "Sapphiron's Demise (25 player)", "ac=573" };
		{ "Kel'Thuzad's Defeat (10 player)", "ac=574" };
		{ "Kel'Thuzad's Defeat (25 player)", "ac=575" };
		{ "The Fall of Naxxramas (10 player)", "ac=576" };
		{ "The Fall of Naxxramas (25 player)", "ac=577" };
		{ "The Dedicated Few (10 player)", "ac=578" };
		{ "The Dedicated Few (25 player)", "ac=579" };
		{ "Arachnophobia (10 player)", "ac=1858" };
		{ "Arachnophobia (25 player)", "ac=1859" };
		{ "Make Quick Werk of Him (10 player)", "ac=1856" };
		{ "Make Quick Werk of Him (25 player)", "ac=1857" };
		{ "The Safety Dance (10 player)", "ac=1996" };
		{ "The Safety Dance (25 player)", "ac=2139" };
		{ "Momma Said Knock You Out (10 player)", "ac=1997" };
		{ "Momma Said Knock You Out (25 player)", "ac=2140" };
		{ "Shocking! (10 player)", "ac=2178" };
		{ "Shocking! (25 player)", "ac=2179" };
		{ "Subtraction (10 player)", "ac=2180" };
		{ "Subtraction (25 player)", "ac=2181" };
		{ "Spore Loser (10 player)", "ac=2182" };
		{ "Spore Loser (25 player)", "ac=2183" };
		{ "And They Would All Go Down Together (10 player)", "ac=2176" };
		{ "And They Would All Go Down Together (25 player)", "ac=2177" };
		{ "The Hundred Club (10 player)", "ac=2146" };
		{ "The Hundred Club (25 player)", "ac=2147" };
		{ "Just Can't Get Enough (10 player)", "ac=2184" };
		{ "Just Can't Get Enough (25 player)", "ac=2185" };
		{ "Just Can't Get Enough - Guild Edition", "ac=5016" };
		{ "Atiesh, Greatstaff of the Guardian", "ac=425" };
		{ "The Undying", "ac=2187" };
		{ "The Immortal", "ac=2186" };
		{ "Realm First! Conqueror of Naxxramas", "ac=1402" };
	};
	ObsidianSanctum = {
		ZoneName = { BZ["Wyrmrest Temple"]..ALC["Colon"]..BZ["The Obsidian Sanctum"] };
		Location = { BZ["Dragonblight"] };
		DungeonID = "224";
		DungeonHeroicID = "238";
		Acronym = L["OS"];
		PlayerLimit = "10/25";
		WorldMapID = "531";
		JournalInstanceID = "755";
		Module = "Atlas_WrathoftheLichKing";
		{ ORNG..ALC["AKA"]..ALC["Colon"]..L["Black Dragonflight Chamber"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Tenebron"), 10002 };
		{ WHIT.." 2) "..Atlas_GetBossName("Shadron"), 10003 };
		{ WHIT.." 3) "..Atlas_GetBossName("Vesperon"), 10004 };
		{ WHIT.." 4) "..Atlas_GetBossName("Sartharion", 1616), 1616 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Besting the Black Dragonflight (10 player)", "ac=1876" };
		{ "Besting the Black Dragonflight (25 player)", "ac=625" };
		{ "Less Is More (10 player)", "ac=624" };
		{ "Less Is More (25 player)", "ac=1877" };
		{ "Gonna Go When the Volcano Blows (10 player)", "ac=2047" };
		{ "Gonna Go When the Volcano Blows (25 player)", "ac=2048" };
		{ "Twilight Assist (10 player)", "ac=2049" };
		{ "Twilight Duo (10 player)", "ac=2050" };
		{ "The Twilight Zone (10 player)", "ac=2051" };
		{ "Twilight Assist (25 player)", "ac=2052" };
		{ "Twilight Duo (25 player)", "ac=2053" };
		{ "The Twilight Zone (25 player)", "ac=2054" };
		{ "The Twilight Zone - Guild Edition", "ac=5017" };
		{ "Realm First! Obsidian Slayer", "ac=456" };
	};
	OnyxiasLair = {
		ZoneName = { BZ["Onyxia's Lair"] };
		Location = { BZ["Dustwallow Marsh"] };
		DungeonID = "46";
		DungeonHeroicID = "257";
		Acronym = L["Ony"];
		PlayerLimit = "10/25";
		WorldMapID = "718";
		JournalInstanceID = "760";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Onyxia", 1651), 1651 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "More Dots! (10 player)", "ac=4402" };
		{ "More Dots! (25 player)", "ac=4405" };
		{ "Many Whelps! Handle It! (10 player)", "ac=4403" };
		{ "Many Whelps! Handle It! (25 player)", "ac=4406" };
		{ "She Deep Breaths More (10 player)", "ac=4404" };
		{ "She Deep Breaths More (25 player)", "ac=4407" };
		{ "Onyxia's Lair (Level 60)", "ac=684" };
		{ "Onyxia's Lair (10 player)", "ac=4396" };
		{ "Onyxia's Lair (25 player)", "ac=4397" };
	};
	RubySanctum = {
		ZoneName = { BZ["Wyrmrest Temple"]..ALC["Colon"]..BZ["The Ruby Sanctum"] };
		Location = { BZ["Dragonblight"] };
		DungeonID = "293";
		DungeonHeroicID = "294";
		Acronym = L["RS"];
		PlayerLimit = "10/25";
		WorldMapID = "609";
		JournalInstanceID = "761";
		Module = "Atlas_WrathoftheLichKing";
		{ ORNG..ALC["AKA"]..ALC["Colon"]..L["Red Dragonflight Chamber"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Baltharus the Warborn"), 10002 };
		{ WHIT.." 2) "..Atlas_GetBossName("Saviana Ragefire"), 10003 };
		{ WHIT.." 3) "..Atlas_GetBossName("General Zarithrian"), 10004 };
		{ WHIT.." 4) "..Atlas_GetBossName("Halion", 1652), 1652 };		
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Twilight Destroyer (10 player)", "ac=4817" };
		{ "The Twilight Destroyer (25 player)", "ac=4815" };
		{ "The Twilight Destroyer - Guild Edition", "ac=5022" };
		{ "Heroic: The Twilight Destroyer (10 player)", "ac=4818" };
		{ "Heroic: The Twilight Destroyer (25 player)", "ac=4816" };
	};
	TheEyeOfEternity = {
		ZoneName = { BZ["The Nexus"]..ALC["Colon"]..BZ["The Eye of Eternity"] };
		Location = { BZ["Borean Tundra"] };
		DungeonID = "223";
		DungeonHeroicID = "237";
		Acronym = L["TEoE"];
		PlayerLimit = "10/25";
		WorldMapID = "527";
		JournalInstanceID = "756";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["Slash"]..ALC["Exit"]..ALC["L-Parenthesis"]..ALC["Portal"]..ALC["R-Parenthesis"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Malygos", 1617), 1617 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Spellweaver's Downfall (10 player)", "ac=622" };
		{ "The Spellweaver's Downfall (25 player)", "ac=623" };
		{ "You Don't Have an Eternity (10 player)", "ac=1874" };
		{ "You Don't Have an Eternity (25 player)", "ac=1875" };
		{ "A Poke in the Eye (10 player)", "ac=1869" };
		{ "A Poke in the Eye (25 player)", "ac=1870" };
		{ "Denyin' the Scion (10 player)", "ac=2148" };
		{ "Denyin' the Scion (25 player)", "ac=2149" };
		{ "You Don't Have an Eternity - Guild Edition", "ac=5018" };
		{ "Realm First! Magic Seeker", "ac=1400" };
	};
	TheNexus = {
		ZoneName = { BZ["The Nexus"]..ALC["Colon"]..BZ["The Nexus"] };
		Location = { BZ["Borean Tundra"] };
		DungeonID = "225";
		DungeonHeroicID = "226";
		Acronym = L["Nex, Nexus"];
		WorldMapID = "520";
		JournalInstanceID = "281";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Warmage Kaitlyn"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Commander Kolurg", 833)..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"], 833 };
		{ WHIT..INDENT..Atlas_GetBossName("Commander Stoutbeard", 617)..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["Comma"]..ALC["Heroic"]..ALC["R-Parenthesis"], 617 };
		{ GREN..INDENT..L["Berinand's Research"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Grand Magus Telestra", 618), 618 };
		{ WHIT.." 3) "..Atlas_GetBossName("Anomalus", 619), 619 };
		{ WHIT.." 4) "..Atlas_GetBossName("Ormorok the Tree-Shaper", 620), 620 };
		{ WHIT.." 5) "..Atlas_GetBossName("Keristrasza", 621), 621 };
		{ GREN.." 1') "..L["Elder Igasho"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10002 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Nexus", "ac=478" };
		{ "Split Personality", "ac=2150" };
		{ "Intense Cold", "ac=2036" };
		{ "Chaos Theory", "ac=2037" };
		{ "Heroic: The Nexus", "ac=490" };
		{ "Heroic: The Nexus Guild Run", "ac=5096" };
	};
	TheOculus = {
		ZoneName = { BZ["The Nexus"]..ALC["Colon"]..BZ["The Oculus"] };
		Location = { BZ["The Nexus"] };
		DungeonID = "206";
		DungeonHeroicID = "211";
		Acronym = L["Ocu"];
		WorldMapID = "528";
		JournalInstanceID = "282";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..ALC["Portal"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Drakos the Interrogator", 622)..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"], 622 };
		{ GREN..INDENT..L["Belgaristrasz"] };
		{ GREN..INDENT..L["Eternos"] };
		{ GREN..INDENT..L["Verdisa"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Varos Cloudstrider", 623), 623 };
		{ WHIT.." 3) "..Atlas_GetBossName("Mage-Lord Urom", 624)..ALC["L-Parenthesis"]..ALC["Middle"]..ALC["R-Parenthesis"], 624 };
		{ WHIT.." 4) "..Atlas_GetBossName("Ley-Guardian Eregos", 625)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 625 };
		{ GREN.." 1') "..L["Centrifuge Construct"], 10003 };
		{ GREN.." 2') "..L["Cache of Eregos"]..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 10004 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Oculus", "ac=487" };
		{ "Experienced Drake Rider", "ac=1871" };
		{ "Make It Count", "ac=1868" };
		{ "Ruby Void", "ac=2044" };
		{ "Emerald Void", "ac=2045" };
		{ "Amber Void", "ac=2046" };
		{ "Heroic: The Oculus", "ac=498" };
		{ "Heroic: The Oculus Guild Run", "ac=5104" };
	};
	TrialOfTheChampion = {
		ZoneName = { L["Crusaders' Coliseum"]..ALC["Colon"]..BZ["Trial of the Champion"] };
		Location = { BZ["Icecrown"] };
		DungeonID = "245";
		DungeonHeroicID = "249";
		Acronym = L["Champ"];
		WorldMapID = "542";
		JournalInstanceID = "284";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Grand Champions", 834), 834 };
		{ ORNG..INDENT..Atlas_GetBossName("Grand Champions", 834)..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 834 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Marshal Jacob Alerius", 834, 1), 834 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Ambrose Boltspark", 834, 2), 834 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Colosos", 834, 5), 834 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Jaelyne Evensong", 834, 3), 834 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Lana Stouthammer", 834, 4), 834 };
		{ ORNG..INDENT..Atlas_GetBossName("Grand Champions", 634)..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"], 634 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Mokra the Skullcrusher", 634, 1), 634 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Eressea Dawnsinger", 634, 2), 634 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Runok Wildmane", 634, 3), 634 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Zul'tore", 634, 4), 634 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Deathstalker Visceri", 634, 5), 634 };
		{ WHIT..INDENT..Atlas_GetBossName("Eadric the Pure", 635)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 635 };
		{ WHIT..INDENT..Atlas_GetBossName("Argent Confessor Paletress", 636)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 636 };
		{ WHIT..INDENT..Atlas_GetBossName("The Black Knight", 637), 637 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Argent Confessor", "ac=3802" };
		{ "The Faceroller", "ac=3803" };
		{ "I've Had Worse", "ac=3804" };
		{ "Trial of the Champion", "ac=3778" };
		{ "Trial of the Champion", "ac=4296" };
		{ "Heroic: Trial of the Champion", "ac=4297" };
		{ "Heroic: Trial of the Champion", "ac=4298" };
		{ "Heroic: Trial of the Champion Guild Run", "ac=5110" };
		{ "Heroic: Trial of the Champion Guild Run", "ac=5111" };
	};
	TrialOfTheCrusader = {
		ZoneName = { L["Crusaders' Coliseum"]..ALC["Colon"]..BZ["Trial of the Crusader"] };
		Location = { BZ["Icecrown"] };
		DungeonID = "246";
		DungeonHeroicID = "248";
		Acronym = L["Crus"];
		PlayerLimit = "10/25";
		WorldMapID = "543";
		JournalInstanceID = "757";
		Module = "Atlas_WrathoftheLichKing";
		{ ORNG..L["Heroic: Trial of the Grand Crusader"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..L["Cavern Entrance"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("The Northrend Beasts", 1618), 1618 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Gormok the Impaler") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Acidmaw") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Dreadscale") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Icehowl") };
		{ WHIT..INDENT..Atlas_GetBossName("Lord Jaraxxus", 1619), 1619 };
		{ WHIT..INDENT..Atlas_GetBossName("Faction Champions") };
		{ WHIT..INDENT..Atlas_GetBossName("Twin Val'kyr", 1622), 1622 };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Fjola Lightbane") };
		{ WHIT..INDENT..INDENT..Atlas_GetBossName("Eydis Darkbane") };
		{ WHIT.." 2) "..Atlas_GetBossName("Anub'arak", 1623), 1623 };
		-- Champion of the Alliance, 1620
		-- Champion of the Horde, 1621
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Call of the Crusade (10 player)", "ac=3917" };
		{ "Call of the Grand Crusade (10 player)", "ac=3918" };
		{ "Call of the Crusade (25 player)", "ac=3916" };
		{ "Call of the Grand Crusade (25 player)", "ac=3812" };
		{ "Upper Back Pain (10 player)", "ac=3797" };
		{ "Upper Back Pain (25 player)", "ac=3813" };
		{ "Not One, But Two Jormungars (10 player)", "ac=3936" };
		{ "Not One, But Two Jormungars (25 player)", "ac=3937" };
		{ "Three Sixty Pain Spike (10 player)", "ac=3996" };
		{ "Three Sixty Pain Spike (25 player)", "ac=3997" };
		{ "Resilience Will Fix It (10 player)", "ac=3798" };
		{ "Salt and Pepper (10 player)", "ac=3799" };
		{ "Salt and Pepper (25 player)", "ac=3815" };
		{ "The Traitor King (10 player)", "ac=3800" };
		{ "The Traitor King (25 player)", "ac=3816" };
		{ "A Tribute to Immortality", "ac=4079" };
		{ "A Tribute to Immortality", "ac=4156" };
		{ "A Tribute to Skill (10 player)", "ac=3808" };
		{ "A Tribute to Mad Skill (10 player)", "ac=3809" };
		{ "A Tribute to Insanity (10 player)", "ac=3810" };
		{ "A Tribute to Dedicated Insanity", "ac=4080" };
		{ "A Tribute to Skill (25 player)", "ac=3817" };
		{ "A Tribute to Mad Skill (25 player)", "ac=3818" };
		{ "A Tribute to Insanity (25 player)", "ac=3819" };
		{ "Realm First! Grand Crusader", "ac=4078" };
	};
	UlduarEnt = {
		ZoneName = { BZ["Ulduar"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		LevelRange = "77-83";
		MinLevel = "75";
		PlayerLimit = "5/10/25";
		Acronym = L["Uldu"];
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..BZ["Ulduar"]..ALC["Colon"]..BZ["Halls of Stone"], 10001 };
		{ BLUE.." B) "..BZ["Ulduar"]..ALC["Colon"]..BZ["Halls of Lightning"], 10002 };
		{ BLUE.." C) "..BZ["Ulduar"], 10003 };
		{ GREN.." 1') "..ALC["Meeting Stone"], 10004 };
		{ GREN.." 2') "..ALC["Graveyard"], 10005 };
		{ GREN.." 3') "..L["Shavalius the Fancy <Flight Master>"], 10006 };
		{ GREN..INDENT..L["Chester Copperpot <General & Trade Supplies>"] };
		{ GREN..INDENT..L["Slosh <Food & Drink>"] };
	};
	UlduarA = {
		ZoneName = { BZ["Ulduar"]..ALC["MapA"]..ALC["L-Parenthesis"]..L["The Siege"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "243";
		DungeonHeroicID = "244";
		Acronym = L["Uldu"];
		PlayerLimit = "10/25";
		WorldMapID = "529";
		DungeonLevel = "1";
		JournalInstanceID = "759";
		Module = "Atlas_WrathoftheLichKing";
		NextMap = "UlduarB";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["The Antechamber"], 10002 };
		{ ORNG.." A') "..L["Tower of Life"], 10003 };
		{ ORNG.." B') "..L["Tower of Flame"], 10004 };
		{ ORNG.." C') "..L["Tower of Frost"], 10005 };
		{ ORNG.." D') "..L["Tower of Storms"], 10006 };
		{ WHIT.." 1) "..Atlas_GetBossName("Flame Leviathan", 1637), 1637 };
		{ WHIT.." 2) "..Atlas_GetBossName("Razorscale", 1639)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1639 };
		{ WHIT.." 3) "..Atlas_GetBossName("Ignis the Furnace Master", 1638)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1638 };
		{ WHIT.." 4) "..Atlas_GetBossName("XT-002 Deconstructor", 1640), 1640 };
		{ GREN.." 1') "..BZ["Expedition Base Camp"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10011 };
		{ GREN.." 2') "..BZ["Formation Grounds"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10012 };
		{ GREN.." 3') "..BZ["The Colossal Forge"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10013 };
		{ GREN.." 4') "..BZ["The Scrapyard"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10014 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Siege of Ulduar (10 player)", "ac=2886" };
		{ "The Siege of Ulduar (25 player)", "ac=2887" };
		{ "The Antechamber of Ulduar (10 player)", "ac=2888" };
		{ "The Antechamber of Ulduar (25 player)", "ac=2889" };
		{ "The Keepers of Ulduar (10 player)", "ac=2890" };
		{ "The Keepers of Ulduar (25 player)", "ac=2891" };
		{ "The Descent into Madness (10 player)", "ac=2892" };
		{ "The Descent into Madness (25 player)", "ac=2893" };
		{ "The Secrets of Ulduar (10 player)", "ac=2894" };
		{ "The Secrets of Ulduar (25 player)", "ac=2895" };
		{ "Dwarfageddon (10 player)", "ac=3097" };
		{ "Dwarfageddon (25 player)", "ac=3098" };
		{ "Unbroken (10 player)", "ac=2905" };
		{ "Unbroken (25 player)", "ac=2906" };
		{ "Three Car Garage (10 player)", "ac=2907" };
		{ "Three Car Garage (25 player)", "ac=2908" };
		{ "Take Out Those Turrets (10 player)", "ac=2909" };
		{ "Take Out Those Turrets (25 player)", "ac=2910" };
		{ "Shutout (10 player)", "ac=2911" };
		{ "Shutout (25 player)", "ac=2912" };
		{ "Orbital Bombardment (10 player)", "ac=2913" };
		{ "Orbital Devastation (10 player)", "ac=2914" };
		{ "Nuked from Orbit (10 player)", "ac=2915" };
		{ "Orbit-uary (10 player)", "ac=3056" };
		{ "Orbital Bombardment (25 player)", "ac=2918" };
		{ "Orbital Devastation (25 player)", "ac=2916" };
		{ "Nuked from Orbit (25 player)", "ac=2917" };
		{ "Orbit-uary (25 player)", "ac=3057" };
		{ "A Quick Shave (10 player)", "ac=2919" };
		{ "A Quick Shave (25 player)", "ac=2921" };
		{ "Iron Dwarf, Medium Rare (10 player)", "ac=2923" };
		{ "Iron Dwarf, Medium Rare (25 player)", "ac=2924" };
		{ "Shattered (10 player)", "ac=2925" };
		{ "Shattered (25 player)", "ac=2926" };
		{ "Hot Pocket (10 player)", "ac=2927" };
		{ "Hot Pocket (25 player)", "ac=2928" };
		{ "Stokin' the Furnace (10 player)", "ac=2930" };
		{ "Stokin' the Furnace (25 player)", "ac=2929" };
		{ "Nerf Engineering (10 player)", "ac=2931" };
		{ "Nerf Engineering (25 player)", "ac=2932" };
		{ "Nerf Scrapbots (10 player)", "ac=2933" };
		{ "Nerf Scrapbots (25 player)", "ac=2935" };
		{ "Nerf Gravity Bombs (10 player)", "ac=2934" };
		{ "Nerf Gravity Bombs (25 player)", "ac=2936" };
		{ "Must Deconstruct Faster (10 player)", "ac=2937" };
		{ "Must Deconstruct Faster (25 player)", "ac=2938" };
		{ "Heartbreaker (10 player)", "ac=3058" };
		{ "Heartbreaker (25 player)", "ac=3059" };
		{ "I Choose You, Runemaster Molgeim (10 player)", "ac=2939" };
		{ "I Choose You, Runemaster Molgeim (25 player)", "ac=2942" };
		{ "I Choose You, Stormcaller Brundir (10 player)", "ac=2940" };
		{ "I Choose You, Stormcaller Brundir (25 player)", "ac=2943" };
		{ "I Choose You, Steelbreaker (10 player)", "ac=2941" };
		{ "I Choose You, Steelbreaker (25 player)", "ac=2944" };
		{ "But I'm On Your Side (10 player)", "ac=2945" };
		{ "But I'm On Your Side (25 player)", "ac=2946" };
		{ "Can't Do That While Stunned (10 player)", "ac=2947" };
		{ "Can't Do That While Stunned (25 player)", "ac=2948" };
		{ "With Open Arms (10 player)", "ac=2951" };
		{ "With Open Arms (25 player)", "ac=2952" };
		{ "Disarmed (10 player)", "ac=2953" };
		{ "Disarmed (25 player)", "ac=2954" };
		{ "If Looks Could Kill (10 player)", "ac=2955" };
		{ "If Looks Could Kill (25 player)", "ac=2956" };
		{ "Rubble and Roll (10 player)", "ac=2959" };
		{ "Rubble and Roll (25 player)", "ac=2960" };
		{ "Crazy Cat Lady (10 player)", "ac=3006" };
		{ "Crazy Cat Lady (25 player)", "ac=3007" };
		{ "Nine Lives (10 player)", "ac=3076" };
		{ "Nine Lives (25 player)", "ac=3077" };
		{ "Cheese the Freeze (10 player)", "ac=2961" };
		{ "Cheese the Freeze (25 player)", "ac=2962" };
		{ "I Have the Coolest Friends (10 player)", "ac=2963" };
		{ "I Have the Coolest Friends (25 player)", "ac=2965" };
		{ "Getting Cold in Here (10 player)", "ac=2967" };
		{ "Getting Cold in Here (25 player)", "ac=2968" };
		{ "I Could Say That This Cache Was Rare (10 player)", "ac=3182" };
		{ "I Could Say That This Cache Was Rare (25 player)", "ac=3184" };
		{ "Staying Buffed All Winter (10 player)", "ac=2969" };
		{ "Staying Buffed All Winter (25 player)", "ac=2970" };
		{ "Don't Stand in the Lightning (10 player)", "ac=2971" };
		{ "Don't Stand in the Lightning (25 player)", "ac=2972" };
		{ "I'll Take You All On (10 player)", "ac=2973" };
		{ "I'll Take You All On (25 player)", "ac=2974" };
		{ "Who Needs Bloodlust? (10 player)", "ac=2975" };
		{ "Who Needs Bloodlust? (25 player)", "ac=2976" };
		{ "Siffed (10 player)", "ac=2977" };
		{ "Siffed (25 player)", "ac=2978" };
		{ "Lose Your Illusion (10 player)", "ac=3176" };
		{ "Lose Your Illusion (25 player)", "ac=3183" };
		{ "Lumberjacked (10 player)", "ac=2979" };
		{ "Lumberjacked (25 player)", "ac=3118" };
		{ "Con-speed-atory (10 player)", "ac=2980" };
		{ "Con-speed-atory (25 player)", "ac=2981" };
		{ "Deforestation (10 player)", "ac=2985" };
		{ "Deforestation (25 player)", "ac=2984" };
		{ "Getting Back to Nature (10 player)", "ac=2982" };
		{ "Getting Back to Nature (25 player)", "ac=2983" };
		{ "Knock on Wood (10 player)", "ac=3177" };
		{ "Knock, Knock on Wood (10 player)", "ac=3178" };
		{ "Knock, Knock, Knock on Wood (10 player)", "ac=3179" };
		{ "Knock on Wood (25 player)", "ac=3185" };
		{ "Knock, Knock on Wood (25 player)", "ac=3186" };
		{ "Knock, Knock, Knock on Wood (25 player)", "ac=3187" };
		{ "Set Up Us the Bomb (10 player)", "ac=2989" };
		{ "Set Up Us the Bomb (25 player)", "ac=3237" };
		{ "Not-So-Friendly Fire (10 player)", "ac=3138" };
		{ "Not-So-Friendly Fire (25 player)", "ac=2995" };
		{ "Firefighter (10 player)", "ac=3180" };
		{ "Firefighter (25 player)", "ac=3189" };
		{ "Shadowdodger (10 player)", "ac=2996" };
		{ "Shadowdodger (25 player)", "ac=2997" };
		{ "I Love the Smell of Saronite in the Morning (10 player)", "ac=3181" };
		{ "I Love the Smell of Saronite in the Morning (25 player)", "ac=3188" };
		{ "Kiss and Make Up (10 player)", "ac=3009" };
		{ "Kiss and Make Up (25 player)", "ac=3011" };
		{ "Three Lights in the Darkness (10 player)", "ac=3157" };
		{ "Two Lights in the Darkness (10 player)", "ac=3141" };
		{ "One Light in the Darkness (10 player)", "ac=3158" };
		{ "Alone in the Darkness (10 player)", "ac=3159" };
		{ "Three Lights in the Darkness (25 player)", "ac=3161" };
		{ "Two Lights in the Darkness (25 player)", "ac=3162" };
		{ "One Light in the Darkness (25 player)", "ac=3163" };
		{ "Alone in the Darkness (25 player)", "ac=3164" };
		{ "Drive Me Crazy (10 player)", "ac=3008" };
		{ "Drive Me Crazy (25 player)", "ac=3010" };
		{ "He's Not Getting Any Older (10 player)", "ac=3012" };
		{ "He's Not Getting Any Older (25 player)", "ac=3013" };
		{ "They're Coming Out of the Walls (10 player)", "ac=3014" };
		{ "They're Coming Out of the Walls (25 player)", "ac=3017" };
		{ "In His House He Waits Dreaming (10 player)", "ac=3015" };
		{ "In His House He Waits Dreaming (25 player)", "ac=3016" };
		{ "Observed (10 player)", "ac=3036" };
		{ "Observed (25 player)", "ac=3037" };
		{ "Supermassive (10 player)", "ac=3003" };
		{ "Supermassive (25 player)", "ac=3002" };
		{ "Alone in the Darkness - Guild Edition", "ac=5019" };
		{ "Observed - Guild Edition", "ac=5020" };
		{ "He Feeds On Your Tears (10 player)", "ac=3004" };
		{ "Val'anyr, Hammer of Ancient Kings", "ac=3142" };
		{ "He Feeds On Your Tears (25 player)", "ac=3005" };
		{ "Herald of the Titans", "ac=3316" };
		{ "Champion of Ulduar", "ac=2903" };
		{ "Conqueror of Ulduar", "ac=2904" };
		{ "Realm First! Death's Demise", "ac=3117" };
		{ "Realm First! Celestial Defender", "ac=3259" };
	};
	UlduarB = {
		ZoneName = { BZ["Ulduar"]..ALC["MapB"]..ALC["L-Parenthesis"]..BZ["The Antechamber"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "243";
		DungeonHeroicID = "244";
		Acronym = L["Uldu"];
		PlayerLimit = "10/25";
		WorldMapID = "529";
		DungeonLevel = "2";
		JournalInstanceID = "759";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "UlduarA";
		NextMap = "UlduarC";
		{ BLUE.." B) "..L["The Siege"], 10001 };
		{ BLUE.." C) "..L["The Keepers"], 10002 };
		{ WHIT.." 5) "..Atlas_GetBossName("The Assembly of Iron", 1641)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1641 };
		{ WHIT..INDENT..Atlas_GetBossName("Steelbreaker") };
		{ WHIT..INDENT..Atlas_GetBossName("Runemaster Molgeim") };
		{ WHIT..INDENT..Atlas_GetBossName("Stormcaller Brundir") };
		{ WHIT.." 6) "..Atlas_GetBossName("Kologarn", 1642), 1642 };
		{ WHIT.." 7) "..Atlas_GetBossName("Algalon the Observer", 1650)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1650 };
		{ GREN.." 5') "..BZ["The Antechamber"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10006 };
		{ GREN.." 6') "..L["Prospector Doren"], 10007 };
		{ GREN..INDENT..L["Archivum Console"] };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Siege of Ulduar (10 player)", "ac=2886" };
		{ "The Siege of Ulduar (25 player)", "ac=2887" };
		{ "The Antechamber of Ulduar (10 player)", "ac=2888" };
		{ "The Antechamber of Ulduar (25 player)", "ac=2889" };
		{ "The Keepers of Ulduar (10 player)", "ac=2890" };
		{ "The Keepers of Ulduar (25 player)", "ac=2891" };
		{ "The Descent into Madness (10 player)", "ac=2892" };
		{ "The Descent into Madness (25 player)", "ac=2893" };
		{ "The Secrets of Ulduar (10 player)", "ac=2894" };
		{ "The Secrets of Ulduar (25 player)", "ac=2895" };
		{ "Dwarfageddon (10 player)", "ac=3097" };
		{ "Dwarfageddon (25 player)", "ac=3098" };
		{ "Unbroken (10 player)", "ac=2905" };
		{ "Unbroken (25 player)", "ac=2906" };
		{ "Three Car Garage (10 player)", "ac=2907" };
		{ "Three Car Garage (25 player)", "ac=2908" };
		{ "Take Out Those Turrets (10 player)", "ac=2909" };
		{ "Take Out Those Turrets (25 player)", "ac=2910" };
		{ "Shutout (10 player)", "ac=2911" };
		{ "Shutout (25 player)", "ac=2912" };
		{ "Orbital Bombardment (10 player)", "ac=2913" };
		{ "Orbital Devastation (10 player)", "ac=2914" };
		{ "Nuked from Orbit (10 player)", "ac=2915" };
		{ "Orbit-uary (10 player)", "ac=3056" };
		{ "Orbital Bombardment (25 player)", "ac=2918" };
		{ "Orbital Devastation (25 player)", "ac=2916" };
		{ "Nuked from Orbit (25 player)", "ac=2917" };
		{ "Orbit-uary (25 player)", "ac=3057" };
		{ "A Quick Shave (10 player)", "ac=2919" };
		{ "A Quick Shave (25 player)", "ac=2921" };
		{ "Iron Dwarf, Medium Rare (10 player)", "ac=2923" };
		{ "Iron Dwarf, Medium Rare (25 player)", "ac=2924" };
		{ "Shattered (10 player)", "ac=2925" };
		{ "Shattered (25 player)", "ac=2926" };
		{ "Hot Pocket (10 player)", "ac=2927" };
		{ "Hot Pocket (25 player)", "ac=2928" };
		{ "Stokin' the Furnace (10 player)", "ac=2930" };
		{ "Stokin' the Furnace (25 player)", "ac=2929" };
		{ "Nerf Engineering (10 player)", "ac=2931" };
		{ "Nerf Engineering (25 player)", "ac=2932" };
		{ "Nerf Scrapbots (10 player)", "ac=2933" };
		{ "Nerf Scrapbots (25 player)", "ac=2935" };
		{ "Nerf Gravity Bombs (10 player)", "ac=2934" };
		{ "Nerf Gravity Bombs (25 player)", "ac=2936" };
		{ "Must Deconstruct Faster (10 player)", "ac=2937" };
		{ "Must Deconstruct Faster (25 player)", "ac=2938" };
		{ "Heartbreaker (10 player)", "ac=3058" };
		{ "Heartbreaker (25 player)", "ac=3059" };
		{ "I Choose You, Runemaster Molgeim (10 player)", "ac=2939" };
		{ "I Choose You, Runemaster Molgeim (25 player)", "ac=2942" };
		{ "I Choose You, Stormcaller Brundir (10 player)", "ac=2940" };
		{ "I Choose You, Stormcaller Brundir (25 player)", "ac=2943" };
		{ "I Choose You, Steelbreaker (10 player)", "ac=2941" };
		{ "I Choose You, Steelbreaker (25 player)", "ac=2944" };
		{ "But I'm On Your Side (10 player)", "ac=2945" };
		{ "But I'm On Your Side (25 player)", "ac=2946" };
		{ "Can't Do That While Stunned (10 player)", "ac=2947" };
		{ "Can't Do That While Stunned (25 player)", "ac=2948" };
		{ "With Open Arms (10 player)", "ac=2951" };
		{ "With Open Arms (25 player)", "ac=2952" };
		{ "Disarmed (10 player)", "ac=2953" };
		{ "Disarmed (25 player)", "ac=2954" };
		{ "If Looks Could Kill (10 player)", "ac=2955" };
		{ "If Looks Could Kill (25 player)", "ac=2956" };
		{ "Rubble and Roll (10 player)", "ac=2959" };
		{ "Rubble and Roll (25 player)", "ac=2960" };
		{ "Crazy Cat Lady (10 player)", "ac=3006" };
		{ "Crazy Cat Lady (25 player)", "ac=3007" };
		{ "Nine Lives (10 player)", "ac=3076" };
		{ "Nine Lives (25 player)", "ac=3077" };
		{ "Cheese the Freeze (10 player)", "ac=2961" };
		{ "Cheese the Freeze (25 player)", "ac=2962" };
		{ "I Have the Coolest Friends (10 player)", "ac=2963" };
		{ "I Have the Coolest Friends (25 player)", "ac=2965" };
		{ "Getting Cold in Here (10 player)", "ac=2967" };
		{ "Getting Cold in Here (25 player)", "ac=2968" };
		{ "I Could Say That This Cache Was Rare (10 player)", "ac=3182" };
		{ "I Could Say That This Cache Was Rare (25 player)", "ac=3184" };
		{ "Staying Buffed All Winter (10 player)", "ac=2969" };
		{ "Staying Buffed All Winter (25 player)", "ac=2970" };
		{ "Don't Stand in the Lightning (10 player)", "ac=2971" };
		{ "Don't Stand in the Lightning (25 player)", "ac=2972" };
		{ "I'll Take You All On (10 player)", "ac=2973" };
		{ "I'll Take You All On (25 player)", "ac=2974" };
		{ "Who Needs Bloodlust? (10 player)", "ac=2975" };
		{ "Who Needs Bloodlust? (25 player)", "ac=2976" };
		{ "Siffed (10 player)", "ac=2977" };
		{ "Siffed (25 player)", "ac=2978" };
		{ "Lose Your Illusion (10 player)", "ac=3176" };
		{ "Lose Your Illusion (25 player)", "ac=3183" };
		{ "Lumberjacked (10 player)", "ac=2979" };
		{ "Lumberjacked (25 player)", "ac=3118" };
		{ "Con-speed-atory (10 player)", "ac=2980" };
		{ "Con-speed-atory (25 player)", "ac=2981" };
		{ "Deforestation (10 player)", "ac=2985" };
		{ "Deforestation (25 player)", "ac=2984" };
		{ "Getting Back to Nature (10 player)", "ac=2982" };
		{ "Getting Back to Nature (25 player)", "ac=2983" };
		{ "Knock on Wood (10 player)", "ac=3177" };
		{ "Knock, Knock on Wood (10 player)", "ac=3178" };
		{ "Knock, Knock, Knock on Wood (10 player)", "ac=3179" };
		{ "Knock on Wood (25 player)", "ac=3185" };
		{ "Knock, Knock on Wood (25 player)", "ac=3186" };
		{ "Knock, Knock, Knock on Wood (25 player)", "ac=3187" };
		{ "Set Up Us the Bomb (10 player)", "ac=2989" };
		{ "Set Up Us the Bomb (25 player)", "ac=3237" };
		{ "Not-So-Friendly Fire (10 player)", "ac=3138" };
		{ "Not-So-Friendly Fire (25 player)", "ac=2995" };
		{ "Firefighter (10 player)", "ac=3180" };
		{ "Firefighter (25 player)", "ac=3189" };
		{ "Shadowdodger (10 player)", "ac=2996" };
		{ "Shadowdodger (25 player)", "ac=2997" };
		{ "I Love the Smell of Saronite in the Morning (10 player)", "ac=3181" };
		{ "I Love the Smell of Saronite in the Morning (25 player)", "ac=3188" };
		{ "Kiss and Make Up (10 player)", "ac=3009" };
		{ "Kiss and Make Up (25 player)", "ac=3011" };
		{ "Three Lights in the Darkness (10 player)", "ac=3157" };
		{ "Two Lights in the Darkness (10 player)", "ac=3141" };
		{ "One Light in the Darkness (10 player)", "ac=3158" };
		{ "Alone in the Darkness (10 player)", "ac=3159" };
		{ "Three Lights in the Darkness (25 player)", "ac=3161" };
		{ "Two Lights in the Darkness (25 player)", "ac=3162" };
		{ "One Light in the Darkness (25 player)", "ac=3163" };
		{ "Alone in the Darkness (25 player)", "ac=3164" };
		{ "Drive Me Crazy (10 player)", "ac=3008" };
		{ "Drive Me Crazy (25 player)", "ac=3010" };
		{ "He's Not Getting Any Older (10 player)", "ac=3012" };
		{ "He's Not Getting Any Older (25 player)", "ac=3013" };
		{ "They're Coming Out of the Walls (10 player)", "ac=3014" };
		{ "They're Coming Out of the Walls (25 player)", "ac=3017" };
		{ "In His House He Waits Dreaming (10 player)", "ac=3015" };
		{ "In His House He Waits Dreaming (25 player)", "ac=3016" };
		{ "Observed (10 player)", "ac=3036" };
		{ "Observed (25 player)", "ac=3037" };
		{ "Supermassive (10 player)", "ac=3003" };
		{ "Supermassive (25 player)", "ac=3002" };
		{ "Alone in the Darkness - Guild Edition", "ac=5019" };
		{ "Observed - Guild Edition", "ac=5020" };
		{ "He Feeds On Your Tears (10 player)", "ac=3004" };
		{ "Val'anyr, Hammer of Ancient Kings", "ac=3142" };
		{ "He Feeds On Your Tears (25 player)", "ac=3005" };
		{ "Herald of the Titans", "ac=3316" };
		{ "Champion of Ulduar", "ac=2903" };
		{ "Conqueror of Ulduar", "ac=2904" };
		{ "Realm First! Death's Demise", "ac=3117" };
		{ "Realm First! Celestial Defender", "ac=3259" };
	};
	UlduarC = {
		ZoneName = { BZ["Ulduar"]..ALC["MapC"]..ALC["L-Parenthesis"]..L["The Keepers"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "243";
		DungeonHeroicID = "244";
		Acronym = L["Uldu"];
		PlayerLimit = "10/25";
		WorldMapID = "529";
		DungeonLevel = "3";
		JournalInstanceID = "759";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "UlduarB";
		NextMap = "UlduarD";
		{ BLUE.." C) "..BZ["The Antechamber"], 10001 };
		{ BLUE.." D) "..BZ["The Spark of Imagination"], 10002 };
		{ BLUE.." E) "..BZ["The Descent into Madness"], 10003 };
		{ WHIT.." 8) "..Atlas_GetBossName("Auriaya", 1643)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1643 };
		{ WHIT.." 9) "..Atlas_GetBossName("Hodir", 1644), 1644 };
		{ WHIT.."10) "..Atlas_GetBossName("Thorim", 1645), 1645 };
		{ ORNG..INDENT..L["Sif"] };
		{ WHIT.."11) "..Atlas_GetBossName("Freya", 1646), 1646 };
		{ WHIT.."12) "..Atlas_GetBossName("Elder Brightleaf"), 10008 };
		{ WHIT.."13) "..Atlas_GetBossName("Elder Ironbranch"), 10009 };
		{ WHIT.."14) "..Atlas_GetBossName("Elder Stonebark"), 10010 };
		{ GREN.." 7') "..BZ["The Shattered Walkway"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10011 };
		{ GREN.." 8') "..BZ["The Conservatory of Life"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10012 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Siege of Ulduar (10 player)", "ac=2886" };
		{ "The Siege of Ulduar (25 player)", "ac=2887" };
		{ "The Antechamber of Ulduar (10 player)", "ac=2888" };
		{ "The Antechamber of Ulduar (25 player)", "ac=2889" };
		{ "The Keepers of Ulduar (10 player)", "ac=2890" };
		{ "The Keepers of Ulduar (25 player)", "ac=2891" };
		{ "The Descent into Madness (10 player)", "ac=2892" };
		{ "The Descent into Madness (25 player)", "ac=2893" };
		{ "The Secrets of Ulduar (10 player)", "ac=2894" };
		{ "The Secrets of Ulduar (25 player)", "ac=2895" };
		{ "Dwarfageddon (10 player)", "ac=3097" };
		{ "Dwarfageddon (25 player)", "ac=3098" };
		{ "Unbroken (10 player)", "ac=2905" };
		{ "Unbroken (25 player)", "ac=2906" };
		{ "Three Car Garage (10 player)", "ac=2907" };
		{ "Three Car Garage (25 player)", "ac=2908" };
		{ "Take Out Those Turrets (10 player)", "ac=2909" };
		{ "Take Out Those Turrets (25 player)", "ac=2910" };
		{ "Shutout (10 player)", "ac=2911" };
		{ "Shutout (25 player)", "ac=2912" };
		{ "Orbital Bombardment (10 player)", "ac=2913" };
		{ "Orbital Devastation (10 player)", "ac=2914" };
		{ "Nuked from Orbit (10 player)", "ac=2915" };
		{ "Orbit-uary (10 player)", "ac=3056" };
		{ "Orbital Bombardment (25 player)", "ac=2918" };
		{ "Orbital Devastation (25 player)", "ac=2916" };
		{ "Nuked from Orbit (25 player)", "ac=2917" };
		{ "Orbit-uary (25 player)", "ac=3057" };
		{ "A Quick Shave (10 player)", "ac=2919" };
		{ "A Quick Shave (25 player)", "ac=2921" };
		{ "Iron Dwarf, Medium Rare (10 player)", "ac=2923" };
		{ "Iron Dwarf, Medium Rare (25 player)", "ac=2924" };
		{ "Shattered (10 player)", "ac=2925" };
		{ "Shattered (25 player)", "ac=2926" };
		{ "Hot Pocket (10 player)", "ac=2927" };
		{ "Hot Pocket (25 player)", "ac=2928" };
		{ "Stokin' the Furnace (10 player)", "ac=2930" };
		{ "Stokin' the Furnace (25 player)", "ac=2929" };
		{ "Nerf Engineering (10 player)", "ac=2931" };
		{ "Nerf Engineering (25 player)", "ac=2932" };
		{ "Nerf Scrapbots (10 player)", "ac=2933" };
		{ "Nerf Scrapbots (25 player)", "ac=2935" };
		{ "Nerf Gravity Bombs (10 player)", "ac=2934" };
		{ "Nerf Gravity Bombs (25 player)", "ac=2936" };
		{ "Must Deconstruct Faster (10 player)", "ac=2937" };
		{ "Must Deconstruct Faster (25 player)", "ac=2938" };
		{ "Heartbreaker (10 player)", "ac=3058" };
		{ "Heartbreaker (25 player)", "ac=3059" };
		{ "I Choose You, Runemaster Molgeim (10 player)", "ac=2939" };
		{ "I Choose You, Runemaster Molgeim (25 player)", "ac=2942" };
		{ "I Choose You, Stormcaller Brundir (10 player)", "ac=2940" };
		{ "I Choose You, Stormcaller Brundir (25 player)", "ac=2943" };
		{ "I Choose You, Steelbreaker (10 player)", "ac=2941" };
		{ "I Choose You, Steelbreaker (25 player)", "ac=2944" };
		{ "But I'm On Your Side (10 player)", "ac=2945" };
		{ "But I'm On Your Side (25 player)", "ac=2946" };
		{ "Can't Do That While Stunned (10 player)", "ac=2947" };
		{ "Can't Do That While Stunned (25 player)", "ac=2948" };
		{ "With Open Arms (10 player)", "ac=2951" };
		{ "With Open Arms (25 player)", "ac=2952" };
		{ "Disarmed (10 player)", "ac=2953" };
		{ "Disarmed (25 player)", "ac=2954" };
		{ "If Looks Could Kill (10 player)", "ac=2955" };
		{ "If Looks Could Kill (25 player)", "ac=2956" };
		{ "Rubble and Roll (10 player)", "ac=2959" };
		{ "Rubble and Roll (25 player)", "ac=2960" };
		{ "Crazy Cat Lady (10 player)", "ac=3006" };
		{ "Crazy Cat Lady (25 player)", "ac=3007" };
		{ "Nine Lives (10 player)", "ac=3076" };
		{ "Nine Lives (25 player)", "ac=3077" };
		{ "Cheese the Freeze (10 player)", "ac=2961" };
		{ "Cheese the Freeze (25 player)", "ac=2962" };
		{ "I Have the Coolest Friends (10 player)", "ac=2963" };
		{ "I Have the Coolest Friends (25 player)", "ac=2965" };
		{ "Getting Cold in Here (10 player)", "ac=2967" };
		{ "Getting Cold in Here (25 player)", "ac=2968" };
		{ "I Could Say That This Cache Was Rare (10 player)", "ac=3182" };
		{ "I Could Say That This Cache Was Rare (25 player)", "ac=3184" };
		{ "Staying Buffed All Winter (10 player)", "ac=2969" };
		{ "Staying Buffed All Winter (25 player)", "ac=2970" };
		{ "Don't Stand in the Lightning (10 player)", "ac=2971" };
		{ "Don't Stand in the Lightning (25 player)", "ac=2972" };
		{ "I'll Take You All On (10 player)", "ac=2973" };
		{ "I'll Take You All On (25 player)", "ac=2974" };
		{ "Who Needs Bloodlust? (10 player)", "ac=2975" };
		{ "Who Needs Bloodlust? (25 player)", "ac=2976" };
		{ "Siffed (10 player)", "ac=2977" };
		{ "Siffed (25 player)", "ac=2978" };
		{ "Lose Your Illusion (10 player)", "ac=3176" };
		{ "Lose Your Illusion (25 player)", "ac=3183" };
		{ "Lumberjacked (10 player)", "ac=2979" };
		{ "Lumberjacked (25 player)", "ac=3118" };
		{ "Con-speed-atory (10 player)", "ac=2980" };
		{ "Con-speed-atory (25 player)", "ac=2981" };
		{ "Deforestation (10 player)", "ac=2985" };
		{ "Deforestation (25 player)", "ac=2984" };
		{ "Getting Back to Nature (10 player)", "ac=2982" };
		{ "Getting Back to Nature (25 player)", "ac=2983" };
		{ "Knock on Wood (10 player)", "ac=3177" };
		{ "Knock, Knock on Wood (10 player)", "ac=3178" };
		{ "Knock, Knock, Knock on Wood (10 player)", "ac=3179" };
		{ "Knock on Wood (25 player)", "ac=3185" };
		{ "Knock, Knock on Wood (25 player)", "ac=3186" };
		{ "Knock, Knock, Knock on Wood (25 player)", "ac=3187" };
		{ "Set Up Us the Bomb (10 player)", "ac=2989" };
		{ "Set Up Us the Bomb (25 player)", "ac=3237" };
		{ "Not-So-Friendly Fire (10 player)", "ac=3138" };
		{ "Not-So-Friendly Fire (25 player)", "ac=2995" };
		{ "Firefighter (10 player)", "ac=3180" };
		{ "Firefighter (25 player)", "ac=3189" };
		{ "Shadowdodger (10 player)", "ac=2996" };
		{ "Shadowdodger (25 player)", "ac=2997" };
		{ "I Love the Smell of Saronite in the Morning (10 player)", "ac=3181" };
		{ "I Love the Smell of Saronite in the Morning (25 player)", "ac=3188" };
		{ "Kiss and Make Up (10 player)", "ac=3009" };
		{ "Kiss and Make Up (25 player)", "ac=3011" };
		{ "Three Lights in the Darkness (10 player)", "ac=3157" };
		{ "Two Lights in the Darkness (10 player)", "ac=3141" };
		{ "One Light in the Darkness (10 player)", "ac=3158" };
		{ "Alone in the Darkness (10 player)", "ac=3159" };
		{ "Three Lights in the Darkness (25 player)", "ac=3161" };
		{ "Two Lights in the Darkness (25 player)", "ac=3162" };
		{ "One Light in the Darkness (25 player)", "ac=3163" };
		{ "Alone in the Darkness (25 player)", "ac=3164" };
		{ "Drive Me Crazy (10 player)", "ac=3008" };
		{ "Drive Me Crazy (25 player)", "ac=3010" };
		{ "He's Not Getting Any Older (10 player)", "ac=3012" };
		{ "He's Not Getting Any Older (25 player)", "ac=3013" };
		{ "They're Coming Out of the Walls (10 player)", "ac=3014" };
		{ "They're Coming Out of the Walls (25 player)", "ac=3017" };
		{ "In His House He Waits Dreaming (10 player)", "ac=3015" };
		{ "In His House He Waits Dreaming (25 player)", "ac=3016" };
		{ "Observed (10 player)", "ac=3036" };
		{ "Observed (25 player)", "ac=3037" };
		{ "Supermassive (10 player)", "ac=3003" };
		{ "Supermassive (25 player)", "ac=3002" };
		{ "Alone in the Darkness - Guild Edition", "ac=5019" };
		{ "Observed - Guild Edition", "ac=5020" };
		{ "He Feeds On Your Tears (10 player)", "ac=3004" };
		{ "Val'anyr, Hammer of Ancient Kings", "ac=3142" };
		{ "He Feeds On Your Tears (25 player)", "ac=3005" };
		{ "Herald of the Titans", "ac=3316" };
		{ "Champion of Ulduar", "ac=2903" };
		{ "Conqueror of Ulduar", "ac=2904" };
		{ "Realm First! Death's Demise", "ac=3117" };
		{ "Realm First! Celestial Defender", "ac=3259" };
	};
	UlduarD = {
		ZoneName = { BZ["Ulduar"]..ALC["MapD"]..ALC["L-Parenthesis"]..BZ["The Spark of Imagination"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "243";
		DungeonHeroicID = "244";
		Acronym = L["Uldu"];
		PlayerLimit = "10/25";
		WorldMapID = "529";
		DungeonLevel = "5";
		JournalInstanceID = "759";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "UlduarC";
		NextMap = "UlduarE";
		{ BLUE.." D) "..L["The Keepers"], 10001 };
		{ WHIT.."15) "..Atlas_GetBossName("Mimiron", 1647), 1647 };
		{ GREN.." 9') "..BZ["The Spark of Imagination"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10003 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Siege of Ulduar (10 player)", "ac=2886" };
		{ "The Siege of Ulduar (25 player)", "ac=2887" };
		{ "The Antechamber of Ulduar (10 player)", "ac=2888" };
		{ "The Antechamber of Ulduar (25 player)", "ac=2889" };
		{ "The Keepers of Ulduar (10 player)", "ac=2890" };
		{ "The Keepers of Ulduar (25 player)", "ac=2891" };
		{ "The Descent into Madness (10 player)", "ac=2892" };
		{ "The Descent into Madness (25 player)", "ac=2893" };
		{ "The Secrets of Ulduar (10 player)", "ac=2894" };
		{ "The Secrets of Ulduar (25 player)", "ac=2895" };
		{ "Dwarfageddon (10 player)", "ac=3097" };
		{ "Dwarfageddon (25 player)", "ac=3098" };
		{ "Unbroken (10 player)", "ac=2905" };
		{ "Unbroken (25 player)", "ac=2906" };
		{ "Three Car Garage (10 player)", "ac=2907" };
		{ "Three Car Garage (25 player)", "ac=2908" };
		{ "Take Out Those Turrets (10 player)", "ac=2909" };
		{ "Take Out Those Turrets (25 player)", "ac=2910" };
		{ "Shutout (10 player)", "ac=2911" };
		{ "Shutout (25 player)", "ac=2912" };
		{ "Orbital Bombardment (10 player)", "ac=2913" };
		{ "Orbital Devastation (10 player)", "ac=2914" };
		{ "Nuked from Orbit (10 player)", "ac=2915" };
		{ "Orbit-uary (10 player)", "ac=3056" };
		{ "Orbital Bombardment (25 player)", "ac=2918" };
		{ "Orbital Devastation (25 player)", "ac=2916" };
		{ "Nuked from Orbit (25 player)", "ac=2917" };
		{ "Orbit-uary (25 player)", "ac=3057" };
		{ "A Quick Shave (10 player)", "ac=2919" };
		{ "A Quick Shave (25 player)", "ac=2921" };
		{ "Iron Dwarf, Medium Rare (10 player)", "ac=2923" };
		{ "Iron Dwarf, Medium Rare (25 player)", "ac=2924" };
		{ "Shattered (10 player)", "ac=2925" };
		{ "Shattered (25 player)", "ac=2926" };
		{ "Hot Pocket (10 player)", "ac=2927" };
		{ "Hot Pocket (25 player)", "ac=2928" };
		{ "Stokin' the Furnace (10 player)", "ac=2930" };
		{ "Stokin' the Furnace (25 player)", "ac=2929" };
		{ "Nerf Engineering (10 player)", "ac=2931" };
		{ "Nerf Engineering (25 player)", "ac=2932" };
		{ "Nerf Scrapbots (10 player)", "ac=2933" };
		{ "Nerf Scrapbots (25 player)", "ac=2935" };
		{ "Nerf Gravity Bombs (10 player)", "ac=2934" };
		{ "Nerf Gravity Bombs (25 player)", "ac=2936" };
		{ "Must Deconstruct Faster (10 player)", "ac=2937" };
		{ "Must Deconstruct Faster (25 player)", "ac=2938" };
		{ "Heartbreaker (10 player)", "ac=3058" };
		{ "Heartbreaker (25 player)", "ac=3059" };
		{ "I Choose You, Runemaster Molgeim (10 player)", "ac=2939" };
		{ "I Choose You, Runemaster Molgeim (25 player)", "ac=2942" };
		{ "I Choose You, Stormcaller Brundir (10 player)", "ac=2940" };
		{ "I Choose You, Stormcaller Brundir (25 player)", "ac=2943" };
		{ "I Choose You, Steelbreaker (10 player)", "ac=2941" };
		{ "I Choose You, Steelbreaker (25 player)", "ac=2944" };
		{ "But I'm On Your Side (10 player)", "ac=2945" };
		{ "But I'm On Your Side (25 player)", "ac=2946" };
		{ "Can't Do That While Stunned (10 player)", "ac=2947" };
		{ "Can't Do That While Stunned (25 player)", "ac=2948" };
		{ "With Open Arms (10 player)", "ac=2951" };
		{ "With Open Arms (25 player)", "ac=2952" };
		{ "Disarmed (10 player)", "ac=2953" };
		{ "Disarmed (25 player)", "ac=2954" };
		{ "If Looks Could Kill (10 player)", "ac=2955" };
		{ "If Looks Could Kill (25 player)", "ac=2956" };
		{ "Rubble and Roll (10 player)", "ac=2959" };
		{ "Rubble and Roll (25 player)", "ac=2960" };
		{ "Crazy Cat Lady (10 player)", "ac=3006" };
		{ "Crazy Cat Lady (25 player)", "ac=3007" };
		{ "Nine Lives (10 player)", "ac=3076" };
		{ "Nine Lives (25 player)", "ac=3077" };
		{ "Cheese the Freeze (10 player)", "ac=2961" };
		{ "Cheese the Freeze (25 player)", "ac=2962" };
		{ "I Have the Coolest Friends (10 player)", "ac=2963" };
		{ "I Have the Coolest Friends (25 player)", "ac=2965" };
		{ "Getting Cold in Here (10 player)", "ac=2967" };
		{ "Getting Cold in Here (25 player)", "ac=2968" };
		{ "I Could Say That This Cache Was Rare (10 player)", "ac=3182" };
		{ "I Could Say That This Cache Was Rare (25 player)", "ac=3184" };
		{ "Staying Buffed All Winter (10 player)", "ac=2969" };
		{ "Staying Buffed All Winter (25 player)", "ac=2970" };
		{ "Don't Stand in the Lightning (10 player)", "ac=2971" };
		{ "Don't Stand in the Lightning (25 player)", "ac=2972" };
		{ "I'll Take You All On (10 player)", "ac=2973" };
		{ "I'll Take You All On (25 player)", "ac=2974" };
		{ "Who Needs Bloodlust? (10 player)", "ac=2975" };
		{ "Who Needs Bloodlust? (25 player)", "ac=2976" };
		{ "Siffed (10 player)", "ac=2977" };
		{ "Siffed (25 player)", "ac=2978" };
		{ "Lose Your Illusion (10 player)", "ac=3176" };
		{ "Lose Your Illusion (25 player)", "ac=3183" };
		{ "Lumberjacked (10 player)", "ac=2979" };
		{ "Lumberjacked (25 player)", "ac=3118" };
		{ "Con-speed-atory (10 player)", "ac=2980" };
		{ "Con-speed-atory (25 player)", "ac=2981" };
		{ "Deforestation (10 player)", "ac=2985" };
		{ "Deforestation (25 player)", "ac=2984" };
		{ "Getting Back to Nature (10 player)", "ac=2982" };
		{ "Getting Back to Nature (25 player)", "ac=2983" };
		{ "Knock on Wood (10 player)", "ac=3177" };
		{ "Knock, Knock on Wood (10 player)", "ac=3178" };
		{ "Knock, Knock, Knock on Wood (10 player)", "ac=3179" };
		{ "Knock on Wood (25 player)", "ac=3185" };
		{ "Knock, Knock on Wood (25 player)", "ac=3186" };
		{ "Knock, Knock, Knock on Wood (25 player)", "ac=3187" };
		{ "Set Up Us the Bomb (10 player)", "ac=2989" };
		{ "Set Up Us the Bomb (25 player)", "ac=3237" };
		{ "Not-So-Friendly Fire (10 player)", "ac=3138" };
		{ "Not-So-Friendly Fire (25 player)", "ac=2995" };
		{ "Firefighter (10 player)", "ac=3180" };
		{ "Firefighter (25 player)", "ac=3189" };
		{ "Shadowdodger (10 player)", "ac=2996" };
		{ "Shadowdodger (25 player)", "ac=2997" };
		{ "I Love the Smell of Saronite in the Morning (10 player)", "ac=3181" };
		{ "I Love the Smell of Saronite in the Morning (25 player)", "ac=3188" };
		{ "Kiss and Make Up (10 player)", "ac=3009" };
		{ "Kiss and Make Up (25 player)", "ac=3011" };
		{ "Three Lights in the Darkness (10 player)", "ac=3157" };
		{ "Two Lights in the Darkness (10 player)", "ac=3141" };
		{ "One Light in the Darkness (10 player)", "ac=3158" };
		{ "Alone in the Darkness (10 player)", "ac=3159" };
		{ "Three Lights in the Darkness (25 player)", "ac=3161" };
		{ "Two Lights in the Darkness (25 player)", "ac=3162" };
		{ "One Light in the Darkness (25 player)", "ac=3163" };
		{ "Alone in the Darkness (25 player)", "ac=3164" };
		{ "Drive Me Crazy (10 player)", "ac=3008" };
		{ "Drive Me Crazy (25 player)", "ac=3010" };
		{ "He's Not Getting Any Older (10 player)", "ac=3012" };
		{ "He's Not Getting Any Older (25 player)", "ac=3013" };
		{ "They're Coming Out of the Walls (10 player)", "ac=3014" };
		{ "They're Coming Out of the Walls (25 player)", "ac=3017" };
		{ "In His House He Waits Dreaming (10 player)", "ac=3015" };
		{ "In His House He Waits Dreaming (25 player)", "ac=3016" };
		{ "Observed (10 player)", "ac=3036" };
		{ "Observed (25 player)", "ac=3037" };
		{ "Supermassive (10 player)", "ac=3003" };
		{ "Supermassive (25 player)", "ac=3002" };
		{ "Alone in the Darkness - Guild Edition", "ac=5019" };
		{ "Observed - Guild Edition", "ac=5020" };
		{ "He Feeds On Your Tears (10 player)", "ac=3004" };
		{ "Val'anyr, Hammer of Ancient Kings", "ac=3142" };
		{ "He Feeds On Your Tears (25 player)", "ac=3005" };
		{ "Herald of the Titans", "ac=3316" };
		{ "Champion of Ulduar", "ac=2903" };
		{ "Conqueror of Ulduar", "ac=2904" };
		{ "Realm First! Death's Demise", "ac=3117" };
		{ "Realm First! Celestial Defender", "ac=3259" };
	};
	UlduarE = {
		ZoneName = { BZ["Ulduar"]..ALC["MapE"]..ALC["L-Parenthesis"]..BZ["The Descent into Madness"]..ALC["R-Parenthesis"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "243";
		DungeonHeroicID = "244";
		Acronym = L["Uldu"];
		PlayerLimit = "10/25";
		WorldMapID = "529";
		DungeonLevel = "4";
		JournalInstanceID = "759";
		Module = "Atlas_WrathoftheLichKing";
		PrevMap = "UlduarD";
		{ BLUE.." E) "..L["The Keepers"], 10001 };
		{ WHIT.."16) "..Atlas_GetBossName("General Vezax", 1648), 1648 };
		{ WHIT.."17) "..Atlas_GetBossName("Yogg-Saron", 1649), 1649 };
		{ GREN..INDENT..Atlas_GetBossName("Sara") };
		{ GREN.."10') "..BZ["The Prison of Yogg-Saron"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10004 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "The Siege of Ulduar (10 player)", "ac=2886" };
		{ "The Siege of Ulduar (25 player)", "ac=2887" };
		{ "The Antechamber of Ulduar (10 player)", "ac=2888" };
		{ "The Antechamber of Ulduar (25 player)", "ac=2889" };
		{ "The Keepers of Ulduar (10 player)", "ac=2890" };
		{ "The Keepers of Ulduar (25 player)", "ac=2891" };
		{ "The Descent into Madness (10 player)", "ac=2892" };
		{ "The Descent into Madness (25 player)", "ac=2893" };
		{ "The Secrets of Ulduar (10 player)", "ac=2894" };
		{ "The Secrets of Ulduar (25 player)", "ac=2895" };
		{ "Dwarfageddon (10 player)", "ac=3097" };
		{ "Dwarfageddon (25 player)", "ac=3098" };
		{ "Unbroken (10 player)", "ac=2905" };
		{ "Unbroken (25 player)", "ac=2906" };
		{ "Three Car Garage (10 player)", "ac=2907" };
		{ "Three Car Garage (25 player)", "ac=2908" };
		{ "Take Out Those Turrets (10 player)", "ac=2909" };
		{ "Take Out Those Turrets (25 player)", "ac=2910" };
		{ "Shutout (10 player)", "ac=2911" };
		{ "Shutout (25 player)", "ac=2912" };
		{ "Orbital Bombardment (10 player)", "ac=2913" };
		{ "Orbital Devastation (10 player)", "ac=2914" };
		{ "Nuked from Orbit (10 player)", "ac=2915" };
		{ "Orbit-uary (10 player)", "ac=3056" };
		{ "Orbital Bombardment (25 player)", "ac=2918" };
		{ "Orbital Devastation (25 player)", "ac=2916" };
		{ "Nuked from Orbit (25 player)", "ac=2917" };
		{ "Orbit-uary (25 player)", "ac=3057" };
		{ "A Quick Shave (10 player)", "ac=2919" };
		{ "A Quick Shave (25 player)", "ac=2921" };
		{ "Iron Dwarf, Medium Rare (10 player)", "ac=2923" };
		{ "Iron Dwarf, Medium Rare (25 player)", "ac=2924" };
		{ "Shattered (10 player)", "ac=2925" };
		{ "Shattered (25 player)", "ac=2926" };
		{ "Hot Pocket (10 player)", "ac=2927" };
		{ "Hot Pocket (25 player)", "ac=2928" };
		{ "Stokin' the Furnace (10 player)", "ac=2930" };
		{ "Stokin' the Furnace (25 player)", "ac=2929" };
		{ "Nerf Engineering (10 player)", "ac=2931" };
		{ "Nerf Engineering (25 player)", "ac=2932" };
		{ "Nerf Scrapbots (10 player)", "ac=2933" };
		{ "Nerf Scrapbots (25 player)", "ac=2935" };
		{ "Nerf Gravity Bombs (10 player)", "ac=2934" };
		{ "Nerf Gravity Bombs (25 player)", "ac=2936" };
		{ "Must Deconstruct Faster (10 player)", "ac=2937" };
		{ "Must Deconstruct Faster (25 player)", "ac=2938" };
		{ "Heartbreaker (10 player)", "ac=3058" };
		{ "Heartbreaker (25 player)", "ac=3059" };
		{ "I Choose You, Runemaster Molgeim (10 player)", "ac=2939" };
		{ "I Choose You, Runemaster Molgeim (25 player)", "ac=2942" };
		{ "I Choose You, Stormcaller Brundir (10 player)", "ac=2940" };
		{ "I Choose You, Stormcaller Brundir (25 player)", "ac=2943" };
		{ "I Choose You, Steelbreaker (10 player)", "ac=2941" };
		{ "I Choose You, Steelbreaker (25 player)", "ac=2944" };
		{ "But I'm On Your Side (10 player)", "ac=2945" };
		{ "But I'm On Your Side (25 player)", "ac=2946" };
		{ "Can't Do That While Stunned (10 player)", "ac=2947" };
		{ "Can't Do That While Stunned (25 player)", "ac=2948" };
		{ "With Open Arms (10 player)", "ac=2951" };
		{ "With Open Arms (25 player)", "ac=2952" };
		{ "Disarmed (10 player)", "ac=2953" };
		{ "Disarmed (25 player)", "ac=2954" };
		{ "If Looks Could Kill (10 player)", "ac=2955" };
		{ "If Looks Could Kill (25 player)", "ac=2956" };
		{ "Rubble and Roll (10 player)", "ac=2959" };
		{ "Rubble and Roll (25 player)", "ac=2960" };
		{ "Crazy Cat Lady (10 player)", "ac=3006" };
		{ "Crazy Cat Lady (25 player)", "ac=3007" };
		{ "Nine Lives (10 player)", "ac=3076" };
		{ "Nine Lives (25 player)", "ac=3077" };
		{ "Cheese the Freeze (10 player)", "ac=2961" };
		{ "Cheese the Freeze (25 player)", "ac=2962" };
		{ "I Have the Coolest Friends (10 player)", "ac=2963" };
		{ "I Have the Coolest Friends (25 player)", "ac=2965" };
		{ "Getting Cold in Here (10 player)", "ac=2967" };
		{ "Getting Cold in Here (25 player)", "ac=2968" };
		{ "I Could Say That This Cache Was Rare (10 player)", "ac=3182" };
		{ "I Could Say That This Cache Was Rare (25 player)", "ac=3184" };
		{ "Staying Buffed All Winter (10 player)", "ac=2969" };
		{ "Staying Buffed All Winter (25 player)", "ac=2970" };
		{ "Don't Stand in the Lightning (10 player)", "ac=2971" };
		{ "Don't Stand in the Lightning (25 player)", "ac=2972" };
		{ "I'll Take You All On (10 player)", "ac=2973" };
		{ "I'll Take You All On (25 player)", "ac=2974" };
		{ "Who Needs Bloodlust? (10 player)", "ac=2975" };
		{ "Who Needs Bloodlust? (25 player)", "ac=2976" };
		{ "Siffed (10 player)", "ac=2977" };
		{ "Siffed (25 player)", "ac=2978" };
		{ "Lose Your Illusion (10 player)", "ac=3176" };
		{ "Lose Your Illusion (25 player)", "ac=3183" };
		{ "Lumberjacked (10 player)", "ac=2979" };
		{ "Lumberjacked (25 player)", "ac=3118" };
		{ "Con-speed-atory (10 player)", "ac=2980" };
		{ "Con-speed-atory (25 player)", "ac=2981" };
		{ "Deforestation (10 player)", "ac=2985" };
		{ "Deforestation (25 player)", "ac=2984" };
		{ "Getting Back to Nature (10 player)", "ac=2982" };
		{ "Getting Back to Nature (25 player)", "ac=2983" };
		{ "Knock on Wood (10 player)", "ac=3177" };
		{ "Knock, Knock on Wood (10 player)", "ac=3178" };
		{ "Knock, Knock, Knock on Wood (10 player)", "ac=3179" };
		{ "Knock on Wood (25 player)", "ac=3185" };
		{ "Knock, Knock on Wood (25 player)", "ac=3186" };
		{ "Knock, Knock, Knock on Wood (25 player)", "ac=3187" };
		{ "Set Up Us the Bomb (10 player)", "ac=2989" };
		{ "Set Up Us the Bomb (25 player)", "ac=3237" };
		{ "Not-So-Friendly Fire (10 player)", "ac=3138" };
		{ "Not-So-Friendly Fire (25 player)", "ac=2995" };
		{ "Firefighter (10 player)", "ac=3180" };
		{ "Firefighter (25 player)", "ac=3189" };
		{ "Shadowdodger (10 player)", "ac=2996" };
		{ "Shadowdodger (25 player)", "ac=2997" };
		{ "I Love the Smell of Saronite in the Morning (10 player)", "ac=3181" };
		{ "I Love the Smell of Saronite in the Morning (25 player)", "ac=3188" };
		{ "Kiss and Make Up (10 player)", "ac=3009" };
		{ "Kiss and Make Up (25 player)", "ac=3011" };
		{ "Three Lights in the Darkness (10 player)", "ac=3157" };
		{ "Two Lights in the Darkness (10 player)", "ac=3141" };
		{ "One Light in the Darkness (10 player)", "ac=3158" };
		{ "Alone in the Darkness (10 player)", "ac=3159" };
		{ "Three Lights in the Darkness (25 player)", "ac=3161" };
		{ "Two Lights in the Darkness (25 player)", "ac=3162" };
		{ "One Light in the Darkness (25 player)", "ac=3163" };
		{ "Alone in the Darkness (25 player)", "ac=3164" };
		{ "Drive Me Crazy (10 player)", "ac=3008" };
		{ "Drive Me Crazy (25 player)", "ac=3010" };
		{ "He's Not Getting Any Older (10 player)", "ac=3012" };
		{ "He's Not Getting Any Older (25 player)", "ac=3013" };
		{ "They're Coming Out of the Walls (10 player)", "ac=3014" };
		{ "They're Coming Out of the Walls (25 player)", "ac=3017" };
		{ "In His House He Waits Dreaming (10 player)", "ac=3015" };
		{ "In His House He Waits Dreaming (25 player)", "ac=3016" };
		{ "Observed (10 player)", "ac=3036" };
		{ "Observed (25 player)", "ac=3037" };
		{ "Supermassive (10 player)", "ac=3003" };
		{ "Supermassive (25 player)", "ac=3002" };
		{ "Alone in the Darkness - Guild Edition", "ac=5019" };
		{ "Observed - Guild Edition", "ac=5020" };
		{ "He Feeds On Your Tears (10 player)", "ac=3004" };
		{ "Val'anyr, Hammer of Ancient Kings", "ac=3142" };
		{ "He Feeds On Your Tears (25 player)", "ac=3005" };
		{ "Herald of the Titans", "ac=3316" };
		{ "Champion of Ulduar", "ac=2903" };
		{ "Conqueror of Ulduar", "ac=2904" };
		{ "Realm First! Death's Demise", "ac=3117" };
		{ "Realm First! Celestial Defender", "ac=3259" };
	};
	UlduarHallsofLightning = {
		ZoneName = { BZ["Ulduar"]..ALC["Colon"]..BZ["Halls of Lightning"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "207";
		DungeonHeroicID = "212";
		Acronym = L["HoL"];
		WorldMapID = "525";
		JournalInstanceID = "275";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Stormherald Eljrrin"] };
		{ WHIT.." 1) "..Atlas_GetBossName("General Bjarngrim", 597)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 597 };
		{ WHIT.." 2) "..Atlas_GetBossName("Volkhan", 598), 598 };
		{ WHIT.." 3) "..Atlas_GetBossName("Ionar", 599), 599 };
		{ WHIT.." 4) "..Atlas_GetBossName("Loken", 600), 600 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Timely Death", "ac=1867" };
		{ "Lightning Struck", "ac=1834" };
		{ "Shatter Resistant", "ac=2042" };
		{ "Halls of Lightning", "ac=486" };
		{ "Heroic: Halls of Lightning", "ac=497" };
		{ "Heroic: Halls of Lightning Guild Run", "ac=5103" };
	};
	UlduarHallsofStone = {
		ZoneName = { BZ["Ulduar"]..ALC["Colon"]..BZ["Halls of Stone"] };
		Location = { BZ["The Storm Peaks"] };
		DungeonID = "208";
		DungeonHeroicID = "213";
		Acronym = L["HoS"];
		WorldMapID = "526";
		JournalInstanceID = "277";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Kaldir Ironbane"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Krystallus", 604), 604 };
		{ WHIT.." 2) "..Atlas_GetBossName("Maiden of Grief", 605), 605 };
		{ WHIT.." 3) "..Atlas_GetBossName("Tribunal of Ages", 606)..ALC["L-Parenthesis"]..ALC["Event"]..ALC["R-Parenthesis"], 606 };
		{ GREN..INDENT..L["Tribunal Chest"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Sjonnir The Ironshaper", 607), 607 };
		{ GREN.." 1') "..L["Elder Yurauk"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 2') "..L["Brann Bronzebeard"], 10003 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Good Grief", "ac=1866" };
		{ "Abuse the Ooze", "ac=2155" };
		{ "Brann Spankin' New", "ac=2154" };
		{ "Halls of Stone", "ac=485" };
		{ "Heroic: Halls of Stone", "ac=496" };
		{ "Heroic: Halls of Stone Guild Run", "ac=5102" };
	};
	UtgardeKeep = {
		ZoneName = { BZ["Utgarde Keep"]..ALC["Colon"]..BZ["Utgarde Keep"] };
		Location = { BZ["Howling Fjord"] };
		DungeonID = "202";
		DungeonHeroicID = "242";
		Acronym = L["UK, Keep"];
		WorldMapID = "523";
		JournalInstanceID = "285";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Defender Mordun"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Dark Ranger Marrah"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ BLUE.." B-C) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Prince Keleseth", 638), 638 };
		{ WHIT.." 2) "..Atlas_GetBossName("Skarvold & Dalronn", 639), 639 };
		{ WHIT.." 3) "..Atlas_GetBossName("Ingvar the Plunderer", 640), 640 };
		{ GREN.." 1') "..L["Elder Jarten"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["Comma"]..ALC["Lower"]..ALC["R-Parenthesis"], 10003 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "On The Rocks", "ac=1919" };
		{ "Utgarde Keep", "ac=477" };
		{ "Heroic: Utgarde Keep", "ac=489" };
		{ "Heroic: Utgarde Keep Guild Run", "ac=5095" };
	};
	UtgardePinnacle = {
		ZoneName = { BZ["Utgarde Keep"]..ALC["Colon"]..BZ["Utgarde Pinnacle"] };
		Location = { BZ["Utgarde Keep"] };
		DungeonID = "203";
		DungeonHeroicID = "205";
		Acronym = L["UP, Pinn"];
		WorldMapID = "524";
		JournalInstanceID = "286";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Brigg Smallshanks"] };
		{ GREN..INDENT..L["Image of Argent Confessor Paletress"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Svala Sorrowgrave", 641), 641 };
		{ WHIT.." 2) "..Atlas_GetBossName("Gortok Palehoof", 642), 642 };
		{ WHIT.." 3) "..Atlas_GetBossName("Skadi the Ruthless", 643), 643 };
		{ WHIT.." 4) "..Atlas_GetBossName("King Ymiron", 644), 644 };
		{ GREN.." 1') "..L["Elder Chogan'gada"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10002 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Hail To The King, Baby", "ac=1790" };
		{ "The Incredible Hulk", "ac=2043" };
		{ "Lodi Dodi We Loves the Skadi", "ac=1873" };
		{ "My Girl Loves to Skadi All the Time", "ac=2156" };
		{ "King's Bane", "ac=2157" };
		{ "Utgarde Pinnacle", "ac=488" };
		{ "Heroic: Utgarde Pinnacle", "ac=499" };
		{ "Heroic: Utgarde Pinnacle Guild Run", "ac=5105" };
	};
	VaultOfArchavon = {
		ZoneName = { BZ["Vault of Archavon"] };
		Location = { BZ["Wintergrasp"] };
		DungeonID = "239";
		DungeonHeroicID = "240";
		Acronym = L["VoA"];
		PlayerLimit = "10/25";
		WorldMapID = "532";
		JournalInstanceID = "753";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Archavon the Stone Watcher", 1597), 1597 };
		{ WHIT.." 2) "..Atlas_GetBossName("Emalon the Storm Watcher", 1598), 1598 };
		{ WHIT.." 3) "..Atlas_GetBossName("Koralon the Flame Watcher", 1599), 1599 };
		{ WHIT.." 4) "..Atlas_GetBossName("Toravon the Ice Watcher", 1600), 1600 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Archavon the Stone Watcher (10 player)", "ac=1722" };
		{ "Archavon the Stone Watcher (25 player)", "ac=1721" };
		{ "Emalon the Storm Watcher (10 player)", "ac=3136" };
		{ "Emalon the Storm Watcher (25 player)", "ac=3137" };
		{ "Koralon the Flame Watcher (10 player)", "ac=3836" };
		{ "Koralon the Flame Watcher (25 player)", "ac=3837" };
		{ "Toravon the Ice Watcher (10 player)", "ac=4585" };
		{ "Toravon the Ice Watcher (25 player)", "ac=4586" };
		{ "Earth, Wind & Fire (10 player)", "ac=4016" };
		{ "Earth, Wind & Fire (25 player)", "ac=4017" };
	};
	VioletHold = {
		ZoneName = { BZ["The Violet Hold"] };
		Location = { BZ["Dalaran (Northrend)"] };
		DungeonID = "220";
		DungeonHeroicID = "221";
		Acronym = L["VH"];
		WorldMapID = "536";
		JournalInstanceID = "283";
		Module = "Atlas_WrathoftheLichKing";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Lieutenant Sinclari"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Erekem", 626)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 626 };
		{ WHIT.." 2) "..Atlas_GetBossName("Zuramat the Obliterator", 631)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"], 631 };
		{ WHIT..INDENT..Atlas_GetBossName("Xevozz", 629)..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["Comma"]..ALC["Random"]..ALC["R-Parenthesis"], 629 };
		{ WHIT.." 3) "..Atlas_GetBossName("Ichoron", 628)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 628 };
		{ WHIT.." 4) "..Atlas_GetBossName("Moragg", 627)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 627 };
		{ WHIT.." 5) "..Atlas_GetBossName("Lavanthor", 630)..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"], 630 };
		{ WHIT.." 6) "..Atlas_GetBossName("Cyanigosa", 632)..ALC["L-Parenthesis"]..ALC["Wave 18"]..ALC["R-Parenthesis"], 632 };
		{ "" };
		{ LBLU..ACHIEVEMENTS..ALC["Colon"] };
		{ "Defenseless", "ac=1816" };
		{ "Lockdown!", "ac=1865" };
		{ "Dehydration", "ac=2041" };
		{ "A Void Dance", "ac=2153" };
		{ "The Violet Hold", "ac=483" };
		{ "Heroic: The Violet Hold", "ac=494" };
		{ "Heroic: The Violet Hold Guild Run", "ac=5100" };
	};
};

for k, v in pairs(myMaps) do
	AtlasMaps[k] = v;
end
